False=false;True=true;previous_post=null;player=null;startup=true;function connect(transport){connectViewer("method="+transport)}function disconnect(){disconnectViewer();$.get("/api/disconnect/"+$(".active-mode #stream-address").val())}function notsupported(transport){window.alert("Sorry but "+transport+" is not supported by your platform. You will need to run AIRi in Linux or Android to use this feature.")}
function updateSensorData(data){$.each(data,function(index,value){if(index=="compass"||index=="gravitation"){var t=value.x+", "+value.y+", "+value.z;$(".active-mode #sensor-"+index).val(t)}else if(index=="magic")$(".active-mode #sensor-"+index).val("0x"+parseInt(value).toString(16));else $(".active-mode #sensor-"+index).val(value)})}
function refreshButton(selector){var text=$(selector+" .ui-btn-text").text();$(selector+" > *").remove();var classes="ui-btn ui-btn-up ui-btn-up-"+$(selector).jqmData("theme")+" ui-btn-inline "+" ui-btn-icon-left ui-btn-icon-right ui-btn-icon-top ui-btn-icon-bottom ui-btn-icon-notext"+" ui-icon-"+$(selector).jqmData("icon")+" ui-icon-shadow ui-btn-corner-all ui-shadow";$(selector).text(text).removeClass(classes).buttonMarkup()}
function internalChangePage(target){console.log("internalChangePage "+target);$.mobile.changePage(target,{"changeHash":false,"reverse":false,"transition":"slide","reloadPage":true})}function goBack(){console.log("goBack");if($.mobile.urlHistory.stack.length==1)return true;if($.mobile.urlHistory.activeIndex==0)return true;var target=$.mobile.urlHistory.getPrev();internalChangePage(target.page.attr("data-url"));$.mobile.urlHistory.stack.pop();$.mobile.urlHistory.stack.pop();return true}
function goHome(){console.log("goHome");internalChangePage("/index.html");return true}function doReload(){console.log("doReload");internalChangePage($.mobile.activePage.attr("data-url"));$.mobile.urlHistory.stack.pop()}
function update_setup(){console.log("setup");$("#setup #exposure-text").remove();b=$("<label id='exposure-text' style='display: inline-block; width: 10%'>ms</label>");$(".ui-page-active #exposure[data-type=range]").after(b);$(".ui-page-active #exposure[data-type=range]").unbind("change");$(".ui-page-active #exposure[data-type=range]").bind("change",function(){var value=$(".ui-page-active #exposure").attr("value");if(value==0)value=1;$(".ui-page-active #exposure-text").text(value*66+" ms")});$(".ui-page-active #exposure").trigger("change")}
function getPlayerApi(){var a=$(".active-mode #video-content").data("flashembed");if(a==null){console.log("no player found");return null}return a.getApi()}
function doVoice(value){if(value==true){if($("#sco_holder").length>0){console.log("Voice all ready enable, not doing again");return}console.log("Enabling voice");var voice=$("<iframe />");voice.attr("id","sco_holder");voice.attr("src","/sco/"+$(".active-mode #stream-address").val());console.log(voice);voice.appendTo("#viewer")}else $("#sco_holder").remove()}
function doConfigure(option,value){$.post("/api/doconfigure/",{"address":$(".active-mode #stream-address").val(),"option":option,"value":value})}function switchResolution(size){return doConfigure("size",size)}function select_changed(){var option=this.id.split("-",2)[1];var value=$("option:selected",this).attr("value");doConfigure(option,value);$(this).selectmenu("refresh")}function switchGeneric(option){doConfigure(option,!eval($(".active-mode #stream-"+option).attr("data-state")))}
function switchFlash(){switchGeneric("flash")}function switchVoice(){switchGeneric("voice")}function updateGeneric(option){if(eval($(".active-mode #stream-"+option).attr("data-notsupported"))==true)return;if(eval($(".active-mode #stream-"+option).attr("data-state"))==true)$(".active-mode #stream-"+option).attr("data-theme","e");else $(".active-mode #stream-"+option).attr("data-theme","a");$(".active-mode #stream-"+option).button()}
function watch_device(){if(currentId()!="viewer")return;if(previous_post!=null)previous_post.abort();previous_post=$.post("/api/updates/",{"address":$("#stream-address").val()},function(data){previous_post=null;console.log(data);if(data.address!=$("#stream-address").val())return watch_device();delete data.address;$.each(data,function(index,element){switch(index){case "size":case "pan":$(".active-mode #stream-"+index+" option:selected").removeAttr("selected");$(".active-mode #stream-"+index+" > option[value="+
element+"]").attr("selected","selected");$(".active-mode #stream-"+index).selectmenu("refresh");break;case "status":if(element==true){$(".active-mode #stream-disconnect").css("display","");$(".active-mode #stream-connect").css("display","none");connectViewer()}else if(element==false){$(".active-mode #stream-connect").css("display","");$(".active-mode #stream-disconnect").css("display","none");disconnectViewer()}$(".active-mode #stream-"+index).val(element);break;case "flash":case "voice":$(".active-mode #stream-"+
index).attr("data-state",element);updateGeneric(index);break;case "client_count":console.log("Client count "+element);$(".ui-page-active #header_extra").text(" | Viewed by "+element);$(".active-mode #stream-"+index).val(element);break;default:console.log("using default handler "+index);$("#stream-"+index).val(element)}});return watch_device()})}function update_viewer(){console.log("view");watch_device();player=$(".active-mode #video-content").flashembed({src:"/media/airi.swf",quality:"low"},{})}
function currentId(){return $(".ui-page-active").attr("id")}
function pageshow(event,ui){var id=currentId();resize();console.log("show "+id);console.log("pagebeforecreate");$.each($(".ui-page").not(".ui-page-active"),function(index,val){console.log("removing: "+$(val).attr("id"))});$(".ui-page").not(".ui-page-active").remove();$("[data-rel=back]").remove();$("#"+id+" #back_button").attr("onclick","javascript: goBack();").removeClass("ui-btn-active");$("#"+id+" #home_button").attr("onclick","javascript: goHome();").removeClass("ui-btn-active");$("#"+id+" #reload_button").attr("onclick",
"javascript: doReload();").removeClass("ui-btn-active");document.title=$(".ui-page-active div[data-role=header] h1").text();window.scrollTo(0,1);if(startup){$.mobile.firstPage.attr("data-url",window.location.pathname+window.location.search);startup=False}switch(id){case "setup":return update_setup();case "viewer":return update_viewer()}console.log("show not known id "+id)}
function pagehide(event,ui){var id=currentId();console.log("hide "+id);switch(id){case "setup":return hide_setup()}console.log("hide not known id "+id)}function create_exposure_slider(label,holder,real){holder=$(holder,$(".ui-page-active"));label=$(label,$(".ui-page-active"));real=$(real,$(".ui-page-active"))}
function viewer_resize(event){var current=$("#viewer .active-mode").attr("data-airi");if(current!=null)if($(window).width()>768&&current=="desktop")return false;if($(window).width()>768){$('#viewer [data-role="tabs"]').addClass("hide");$('#viewer [data-airi="mobile"]').addClass("hide").removeClass("active-mode");$('#viewer [data-airi="desktop"]').removeClass("hide").addClass("active-mode")}else{$('#viewer [data-role="tabs"]').removeClass("hide");$('#viewer [data-airi="mobile"]').removeClass("hide").addClass("active-mode");
$('#viewer [data-airi="desktop"]').addClass("hide").removeClass("active-mode")}return true}
function viewer_create(event){var prepare=function(content){console.log("viewer_create prepare");if(content.attr("id")=="video")$("#viewer .ui-content .active-mode").addClass("ui-video-player");else $("#viewer .ui-content .active-mode").removeClass("ui-video-player")};console.log("creating viewer");$(".rotate-45").rotate(-45);viewer_resize();viewerResize();$("#viewer div[data-role=tabs]").tabs({beforeTabShow:function(event,ui){prepare(ui.nextContent)},load:function(event,args){prepare(args.currentContent)},
selector:"div[data-airi=mobile]"})}function setup_create(event){console.log("creating setup");$("#setup [data-role=tabs]").tabs({selector:"form[id=setup-form]"});$("div[data-role=page][id=setup] #reload_button").addClass("hide")}
function viewerResizeDesktop(width,height){var viewer=$("#viewer .active-mode #video-content");if(width!=undefined&&height!=undefined){console.log("viewerResize",width,height);viewer.data("width",width);viewer.data("height",height)}$("#viewer .active-mode").parent().removeClass("ui-content-marginless");$("#viewer div[data-role=header]").find("a[id!=home_button],h1,h4").removeClass("hide");$("#viewer #home_button").removeClass("top-front");$("object",viewer).css("width",viewer.data("width"));$("object",
viewer).css("height",viewer.data("height"))}function makeFullScreen(selector){var $this=$(selector);$this.addClass("ui-page-fullscreen");$this.find(".ui-header:jqmData(position='fixed')").addClass("ui-header-fixed ui-fixed-inline fade");$this.find(".ui-footer:jqmData(position='fixed')").addClass("ui-footer-fixed ui-fixed-inline fade")}
function makePartialScreen(selector){var $this=$(selector);$this.removeClass("ui-page-fullscreen");$this.find(".ui-header:jqmData(position='fixed')").removeClass("ui-header-fixed ui-fixed-inline fade");$this.find(".ui-footer:jqmData(position='fixed')").removeClass("ui-footer-fixed ui-fixed-inline fade")}
function viewerResizeMobile(width,height){$("#viewer div[data-role=header]").find("a[id=back_button],a[id=reload_button],h1,h4").addClass("hide");$("#viewer #home_button").addClass("top-front");$("#viewer .active-mode").parent().addClass("ui-content-marginless");var height=$(window).height();var width=$(window).width()-50;$.each($("#viewer div[data-role=header]"),function(a,p){height-=$(p).outerHeight()});console.log("new size "+width+" , "+height);$("#viewer .active-mode #video-content").css("width",
width);$("#viewer .active-mode #video-content").css("height",height);$("#viewer .active-mode #video-content").css("margin",0)}function viewerResize(width,height){var current=$("#viewer .active-mode").attr("data-airi");if(current=="mobile")return viewerResizeMobile(width,height);else return viewerResizeDesktop(width,height)}function viewerReady(){console.log("viewerReady");connectViewer()}function hide_setup(){}
function connectViewer(extra){console.log("connectViewer");var player=getPlayerApi();if(player==null)return;var url="/stream/"+$("#stream-address").val().replace(/:/g,"_");url+="?flash=true&uniqId="+(new Date).getTime();if(extra!=null)url+="&"+extra;player.xhrConnect(url)}function disconnectViewer(){console.log("disconnectViewer");var player=getPlayerApi();if(player==null)return;try{player.xhrDisconnect()}catch(err){}}
function switchState(){$.post("/api/switchstate/",{"address":$("#stream-address").val()},function(data){console.log("switchState result",data)})}
function resize(event){if($(window).width()<768)$(".ui-page-active #home_button,#back_button,#reload_button").jqmData("iconpos","notext");else{$(".ui-page-active #home_button,#reload_button").jqmData("iconpos","right");$(".ui-page-active #back_button").jqmData("iconpos","left")}refreshButton(".ui-page-active #home_button");refreshButton(".ui-page-active #back_button");refreshButton(".ui-page-active #reload_button");if(currentId()=="viewer"){var r=viewer_resize(event);viewerResize();if(r)update_viewer()}}
function pagebeforecreate(){}function index_init(){$("div").live("pageshow",pageshow);$("div").live("pagebeforehide",pagehide);$("#viewer").live("pagecreate",viewer_create);$("#setup").live("pagecreate",setup_create);$(window).bind("orientationchange",resize);$(window).bind("resize",resize)}$(document).bind("mobileinit",index_init);(function($,undefined){if($.cleanData){var _cleanData=$.cleanData;$.cleanData=function(elems){for(var i=0,elem;(elem=elems[i])!=null;i++)$(elem).triggerHandler("remove");_cleanData(elems)}}else{var _remove=$.fn.remove;$.fn.remove=function(selector,keepData){return this.each(function(){if(!keepData)if(!selector||$.filter(selector,[this]).length)$("*",this).add([this]).each(function(){$(this).triggerHandler("remove")});return _remove.call($(this),selector,keepData)})}}$.widget=function(name,base,prototype){var namespace=
name.split(".")[0],fullName;name=name.split(".")[1];fullName=namespace+"-"+name;if(!prototype){prototype=base;base=$.Widget}$.expr[":"][fullName]=function(elem){return!!$.data(elem,name)};$[namespace]=$[namespace]||{};$[namespace][name]=function(options,element){if(arguments.length)this._createWidget(options,element)};var basePrototype=new base;basePrototype.options=$.extend(true,{},basePrototype.options);$[namespace][name].prototype=$.extend(true,basePrototype,{namespace:namespace,widgetName:name,
widgetEventPrefix:$[namespace][name].prototype.widgetEventPrefix||name,widgetBaseClass:fullName},prototype);$.widget.bridge(name,$[namespace][name])};$.widget.bridge=function(name,object){$.fn[name]=function(options){var isMethodCall=typeof options==="string",args=Array.prototype.slice.call(arguments,1),returnValue=this;options=!isMethodCall&&args.length?$.extend.apply(null,[true,options].concat(args)):options;if(isMethodCall&&options.charAt(0)==="_")return returnValue;if(isMethodCall)this.each(function(){var instance=
$.data(this,name);if(!instance)throw"cannot call methods on "+name+" prior to initialization; "+"attempted to call method '"+options+"'";if(!$.isFunction(instance[options]))throw"no such method '"+options+"' for "+name+" widget instance";var methodValue=instance[options].apply(instance,args);if(methodValue!==instance&&methodValue!==undefined){returnValue=methodValue;return false}});else this.each(function(){var instance=$.data(this,name);if(instance)instance.option(options||{})._init();else $.data(this,
name,new object(options,this))});return returnValue}};$.Widget=function(options,element){if(arguments.length)this._createWidget(options,element)};$.Widget.prototype={widgetName:"widget",widgetEventPrefix:"",options:{disabled:false},_createWidget:function(options,element){$.data(element,this.widgetName,this);this.element=$(element);this.options=$.extend(true,{},this.options,this._getCreateOptions(),options);var self=this;this.element.bind("remove."+this.widgetName,function(){self.destroy()});this._create();
this._trigger("create");this._init()},_getCreateOptions:function(){var options={};if($.metadata)options=$.metadata.get(element)[this.widgetName];return options},_create:function(){},_init:function(){},destroy:function(){this.element.unbind("."+this.widgetName).removeData(this.widgetName);this.widget().unbind("."+this.widgetName).removeAttr("aria-disabled").removeClass(this.widgetBaseClass+"-disabled "+"ui-state-disabled")},widget:function(){return this.element},option:function(key,value){var options=
key;if(arguments.length===0)return $.extend({},this.options);if(typeof key==="string"){if(value===undefined)return this.options[key];options={};options[key]=value}this._setOptions(options);return this},_setOptions:function(options){var self=this;$.each(options,function(key,value){self._setOption(key,value)});return this},_setOption:function(key,value){this.options[key]=value;if(key==="disabled")this.widget()[value?"addClass":"removeClass"](this.widgetBaseClass+"-disabled"+" "+"ui-state-disabled").attr("aria-disabled",
value);return this},enable:function(){return this._setOption("disabled",false)},disable:function(){return this._setOption("disabled",true)},_trigger:function(type,event,data){var callback=this.options[type];event=$.Event(event);event.type=(type===this.widgetEventPrefix?type:this.widgetEventPrefix+type).toLowerCase();data=data||{};if(event.originalEvent)for(var i=$.event.props.length,prop;i;){prop=$.event.props[--i];event[prop]=event.originalEvent[prop]}this.element.trigger(event,data);return!($.isFunction(callback)&&
callback.call(this.element[0],event,data)===false||event.isDefaultPrevented())}}})(jQuery);(function($,undefined){$.widget("mobile.widget",{_getCreateOptions:function(){var elem=this.element,options={};$.each(this.options,function(option){var value=elem.jqmData(option.replace(/[A-Z]/g,function(c){return"-"+c.toLowerCase()}));if(value!==undefined)options[option]=value});return options}})})(jQuery);
(function($,undefined){var $window=$(window),$html=$("html"),resolutionBreakpoints=[320,480,768,1024];$.mobile.media=function(){var cache={},testDiv=$("<div id='jquery-mediatest'>"),fakeBody=$("<body>").append(testDiv);return function(query){if(!(query in cache)){var styleBlock=document.createElement("style"),cssrule="@media "+query+" { #jquery-mediatest { position:absolute; } }";styleBlock.type="text/css";if(styleBlock.styleSheet)styleBlock.styleSheet.cssText=cssrule;else styleBlock.appendChild(document.createTextNode(cssrule));
$html.prepend(fakeBody).prepend(styleBlock);cache[query]=testDiv.css("position")==="absolute";fakeBody.add(styleBlock).remove()}return cache[query]}}();function detectResolutionBreakpoints(){var currWidth=$window.width(),minPrefix="min-width-",maxPrefix="max-width-",minBreakpoints=[],maxBreakpoints=[],unit="px",breakpointClasses;$html.removeClass(minPrefix+resolutionBreakpoints.join(unit+" "+minPrefix)+unit+" "+maxPrefix+resolutionBreakpoints.join(unit+" "+maxPrefix)+unit);$.each(resolutionBreakpoints,
function(i,breakPoint){if(currWidth>=breakPoint)minBreakpoints.push(minPrefix+breakPoint+unit);if(currWidth<=breakPoint)maxBreakpoints.push(maxPrefix+breakPoint+unit)});if(minBreakpoints.length)breakpointClasses=minBreakpoints.join(" ");if(maxBreakpoints.length)breakpointClasses+=" "+maxBreakpoints.join(" ");$html.addClass(breakpointClasses)}$.mobile.addResolutionBreakpoints=function(newbps){if($.type(newbps)==="array")resolutionBreakpoints=resolutionBreakpoints.concat(newbps);else resolutionBreakpoints.push(newbps);
resolutionBreakpoints.sort(function(a,b){return a-b});detectResolutionBreakpoints()};$(document).bind("mobileinit.htmlclass",function(){var ev=$.support.orientation;$window.bind("orientationchange.htmlclass throttledResize.htmlclass",function(event){if(event.orientation)$html.removeClass("portrait landscape").addClass(event.orientation);detectResolutionBreakpoints()})});$(function(){$window.trigger("orientationchange.htmlclass")})})(jQuery);
(function($,undefined){var fakeBody=$("<body>").prependTo("html"),fbCSS=fakeBody[0].style,vendors=["webkit","moz","o"],webos="palmGetResource"in window,bb=window.blackberry;function propExists(prop){var uc_prop=prop.charAt(0).toUpperCase()+prop.substr(1),props=(prop+" "+vendors.join(uc_prop+" ")+uc_prop).split(" ");for(var v in props)if(fbCSS[v]!==undefined)return true}function baseTagTest(){var fauxBase=location.protocol+"//"+location.host+location.pathname+"ui-dir/",base=$("head base"),fauxEle=
null,href="";if(!base.length)base=fauxEle=$("<base>",{"href":fauxBase}).appendTo("head");else href=base.attr("href");var link=$("<a href='testurl'></a>").prependTo(fakeBody),rebase=link[0].href;base[0].href=href?href:location.pathname;if(fauxEle)fauxEle.remove();return rebase.indexOf(fauxBase)===0}$.mobile.browser={};$.mobile.browser.ie=function(){var v=3,div=document.createElement("div"),a=div.all||[];while(div.innerHTML="<\!--[if gt IE "+ ++v+"]><br><![endif]--\>",a[0]);return v>4?v:!v}();$.extend($.support,
{orientation:"orientation"in window,touch:"ontouchend"in document,cssTransitions:"WebKitTransitionEvent"in window,pushState:!!history.pushState,mediaquery:$.mobile.media("only all"),cssPseudoElement:!!propExists("content"),boxShadow:!!propExists("boxShadow")&&!bb,scrollTop:("pageXOffset"in window||"scrollTop"in document.documentElement||"scrollTop"in fakeBody[0])&&!webos,dynamicBaseTag:baseTagTest(),eventCapture:"addEventListener"in document});fakeBody.remove();if(!$.support.boxShadow)$("html").addClass("ui-mobile-nosupport-boxshadow")})(jQuery);
(function($,window,document,undefined){var dataPropertyName="virtualMouseBindings",touchTargetPropertyName="virtualTouchID",virtualEventNames="vmouseover vmousedown vmousemove vmouseup vclick vmouseout vmousecancel".split(" "),touchEventProps="clientX clientY pageX pageY screenX screenY".split(" "),activeDocHandlers={},resetTimerID=0,startX=0,startY=0,didScroll=false,clickBlockList=[],blockMouseTriggers=false,blockTouchTriggers=false,eventCaptureSupported=$.support.eventCapture,$document=$(document),
nextTouchID=1,lastTouchID=0;$.vmouse={moveDistanceThreshold:10,clickDistanceThreshold:10,resetTimerDuration:1500};function getNativeEvent(event){while(event&&typeof event.originalEvent!=="undefined")event=event.originalEvent;return event}function createVirtualEvent(event,eventType){var t=event.type;event=$.Event(event);event.type=eventType;var oe=event.originalEvent;var props=$.event.props;if(oe)for(var i=props.length,prop;i;){prop=props[--i];event[prop]=oe[prop]}if(t.search(/^touch/)!==-1){var ne=
getNativeEvent(oe),t=ne.touches,ct=ne.changedTouches,touch=t&&t.length?t[0]:ct&&ct.length?ct[0]:undefined;if(touch)for(var i=0,len=touchEventProps.length;i<len;i++){var prop=touchEventProps[i];event[prop]=touch[prop]}}return event}function getVirtualBindingFlags(element){var flags={};while(element){var b=$.data(element,dataPropertyName);for(var k in b)if(b[k])flags[k]=flags.hasVirtualBinding=true;element=element.parentNode}return flags}function getClosestElementWithVirtualBinding(element,eventType){while(element){var b=
$.data(element,dataPropertyName);if(b&&(!eventType||b[eventType]))return element;element=element.parentNode}return null}function enableTouchBindings(){blockTouchTriggers=false}function disableTouchBindings(){blockTouchTriggers=true}function enableMouseBindings(){lastTouchID=0;clickBlockList.length=0;blockMouseTriggers=false;disableTouchBindings()}function disableMouseBindings(){enableTouchBindings()}function startResetTimer(){clearResetTimer();resetTimerID=setTimeout(function(){resetTimerID=0;enableMouseBindings()},
$.vmouse.resetTimerDuration)}function clearResetTimer(){if(resetTimerID){clearTimeout(resetTimerID);resetTimerID=0}}function triggerVirtualEvent(eventType,event,flags){var defaultPrevented=false;if(flags&&flags[eventType]||!flags&&getClosestElementWithVirtualBinding(event.target,eventType)){var ve=createVirtualEvent(event,eventType);$(event.target).trigger(ve);defaultPrevented=ve.isDefaultPrevented()}return defaultPrevented}function mouseEventCallback(event){var touchID=$.data(event.target,touchTargetPropertyName);
if(!blockMouseTriggers&&(!lastTouchID||lastTouchID!==touchID))triggerVirtualEvent("v"+event.type,event)}function handleTouchStart(event){var touches=getNativeEvent(event).touches;if(touches&&touches.length===1){var target=event.target,flags=getVirtualBindingFlags(target);if(flags.hasVirtualBinding){lastTouchID=nextTouchID++;$.data(target,touchTargetPropertyName,lastTouchID);clearResetTimer();disableMouseBindings();didScroll=false;var t=getNativeEvent(event).touches[0];startX=t.pageX;startY=t.pageY;
triggerVirtualEvent("vmouseover",event,flags);triggerVirtualEvent("vmousedown",event,flags)}}}function handleScroll(event){if(blockTouchTriggers)return;if(!didScroll)triggerVirtualEvent("vmousecancel",event,getVirtualBindingFlags(event.target));didScroll=true;startResetTimer()}function handleTouchMove(event){if(blockTouchTriggers)return;var t=getNativeEvent(event).touches[0];var didCancel=didScroll,moveThreshold=$.vmouse.moveDistanceThreshold;didScroll=didScroll||Math.abs(t.pageX-startX)>moveThreshold||
Math.abs(t.pageY-startY)>moveThreshold;var flags=getVirtualBindingFlags(event.target);if(didScroll&&!didCancel)triggerVirtualEvent("vmousecancel",event,flags);triggerVirtualEvent("vmousemove",event,flags);startResetTimer()}function handleTouchEnd(event){if(blockTouchTriggers)return;disableTouchBindings();var flags=getVirtualBindingFlags(event.target);triggerVirtualEvent("vmouseup",event,flags);if(!didScroll)if(triggerVirtualEvent("vclick",event,flags)){var t=getNativeEvent(event).changedTouches[0];
clickBlockList.push({touchID:lastTouchID,x:t.clientX,y:t.clientY});blockMouseTriggers=true}triggerVirtualEvent("vmouseout",event,flags);didScroll=false;startResetTimer()}function hasVirtualBindings(ele){var bindings=$.data(ele,dataPropertyName),k;if(bindings)for(k in bindings)if(bindings[k])return true;return false}function dummyMouseHandler(){}function getSpecialEventObject(eventType){var realType=eventType.substr(1);return{setup:function(data,namespace){if(!hasVirtualBindings(this))$.data(this,
dataPropertyName,{});var bindings=$.data(this,dataPropertyName);bindings[eventType]=true;activeDocHandlers[eventType]=(activeDocHandlers[eventType]||0)+1;if(activeDocHandlers[eventType]===1)$document.bind(realType,mouseEventCallback);$(this).bind(realType,dummyMouseHandler);if(eventCaptureSupported){activeDocHandlers["touchstart"]=(activeDocHandlers["touchstart"]||0)+1;if(activeDocHandlers["touchstart"]===1)$document.bind("touchstart",handleTouchStart).bind("touchend",handleTouchEnd).bind("touchmove",
handleTouchMove).bind("scroll",handleScroll)}},teardown:function(data,namespace){--activeDocHandlers[eventType];if(!activeDocHandlers[eventType])$document.unbind(realType,mouseEventCallback);if(eventCaptureSupported){--activeDocHandlers["touchstart"];if(!activeDocHandlers["touchstart"])$document.unbind("touchstart",handleTouchStart).unbind("touchmove",handleTouchMove).unbind("touchend",handleTouchEnd).unbind("scroll",handleScroll)}var $this=$(this),bindings=$.data(this,dataPropertyName);if(bindings)bindings[eventType]=
false;$this.unbind(realType,dummyMouseHandler);if(!hasVirtualBindings(this))$this.removeData(dataPropertyName)}}}for(var i=0;i<virtualEventNames.length;i++)$.event.special[virtualEventNames[i]]=getSpecialEventObject(virtualEventNames[i]);if(eventCaptureSupported)document.addEventListener("click",function(e){var cnt=clickBlockList.length;var target=e.target;if(cnt){var x=e.clientX,y=e.clientY,threshold=$.vmouse.clickDistanceThreshold;var ele=target;while(ele){for(var i=0;i<cnt;i++){var o=clickBlockList[i],
touchID=0;if(ele===target&&Math.abs(o.x-x)<threshold&&Math.abs(o.y-y)<threshold||$.data(ele,touchTargetPropertyName)===o.touchID){e.preventDefault();e.stopPropagation();return}}ele=ele.parentNode}}},true)})(jQuery,window,document);
(function($,undefined){$.each("touchstart touchmove touchend orientationchange throttledresize tap taphold swipe swipeleft swiperight scrollstart scrollstop".split(" "),function(i,name){$.fn[name]=function(fn){return fn?this.bind(name,fn):this.trigger(name)};$.attrFn[name]=true});var supportTouch=$.support.touch,scrollEvent="touchmove scroll",touchStartEvent=supportTouch?"touchstart":"mousedown",touchStopEvent=supportTouch?"touchend":"mouseup",touchMoveEvent=supportTouch?"touchmove":"mousemove";function triggerCustomEvent(obj,
eventType,event){var originalType=event.type;event.type=eventType;$.event.handle.call(obj,event);event.type=originalType}$.event.special.scrollstart={enabled:true,setup:function(){var thisObject=this,$this=$(thisObject),scrolling,timer;function trigger(event,state){scrolling=state;triggerCustomEvent(thisObject,scrolling?"scrollstart":"scrollstop",event)}$this.bind(scrollEvent,function(event){if(!$.event.special.scrollstart.enabled)return;if(!scrolling)trigger(event,true);clearTimeout(timer);timer=
setTimeout(function(){trigger(event,false)},50)})}};$.event.special.tap={setup:function(){var thisObject=this,$this=$(thisObject);$this.bind("vmousedown",function(event){if(event.which&&event.which!==1)return false;var touching=true,origTarget=event.target,origEvent=event.originalEvent,timer;function clearTapHandlers(){touching=false;clearTimeout(timer);$this.unbind("vclick",clickHandler).unbind("vmousecancel",clearTapHandlers)}function clickHandler(event){clearTapHandlers();if(origTarget==event.target)triggerCustomEvent(thisObject,
"tap",event)}$this.bind("vmousecancel",clearTapHandlers).bind("vclick",clickHandler);timer=setTimeout(function(){if(touching)triggerCustomEvent(thisObject,"taphold",event)},750)})}};$.event.special.swipe={setup:function(){var thisObject=this,$this=$(thisObject);$this.bind(touchStartEvent,function(event){var data=event.originalEvent.touches?event.originalEvent.touches[0]:event,start={time:(new Date).getTime(),coords:[data.pageX,data.pageY],origin:$(event.target)},stop;function moveHandler(event){if(!start)return;
var data=event.originalEvent.touches?event.originalEvent.touches[0]:event;stop={time:(new Date).getTime(),coords:[data.pageX,data.pageY]};if(Math.abs(start.coords[0]-stop.coords[0])>10)event.preventDefault()}$this.bind(touchMoveEvent,moveHandler).one(touchStopEvent,function(event){$this.unbind(touchMoveEvent,moveHandler);if(start&&stop)if(stop.time-start.time<1E3&&Math.abs(start.coords[0]-stop.coords[0])>30&&Math.abs(start.coords[1]-stop.coords[1])<75)start.origin.trigger("swipe").trigger(start.coords[0]>
stop.coords[0]?"swipeleft":"swiperight");start=stop=undefined})})}};(function($){var win=$(window),special_event,get_orientation,last_orientation;$.event.special.orientationchange=special_event={setup:function(){if($.support.orientation)return false;last_orientation=get_orientation();win.bind("throttledresize",handler)},teardown:function(){if($.support.orientation)return false;win.unbind("throttledresize",handler)},add:function(handleObj){var old_handler=handleObj.handler;handleObj.handler=function(event){event.orientation=
get_orientation();return old_handler.apply(this,arguments)}}};function handler(){var orientation=get_orientation();if(orientation!==last_orientation){last_orientation=orientation;win.trigger("orientationchange")}}$.event.special.orientationchange.orientation=get_orientation=function(){var elem=document.documentElement;return elem&&elem.clientWidth/elem.clientHeight<1.1?"portrait":"landscape"}})(jQuery);(function(){$.event.special.throttledresize={setup:function(){$(this).bind("resize",handler)},teardown:function(){$(this).unbind("resize",
handler)}};var throttle=250,handler=function(){curr=(new Date).getTime();diff=curr-lastCall;if(diff>=throttle){lastCall=curr;$(this).trigger("throttledresize")}else{if(heldCall)clearTimeout(heldCall);heldCall=setTimeout(handler,throttle-diff)}},lastCall=0,heldCall,curr,diff})();$.each({scrollstop:"scrollstart",taphold:"tap",swipeleft:"swipe",swiperight:"swipe"},function(event,sourceEvent){$.event.special[event]={setup:function(){$(this).bind(sourceEvent,$.noop)}}})})(jQuery);
(function($,window,undefined){"$:nomunge";var str_hashchange="hashchange",doc=document,fake_onhashchange,special=$.event.special,doc_mode=doc.documentMode,supports_onhashchange="on"+str_hashchange in window&&(doc_mode===undefined||doc_mode>7);function get_fragment(url){url=url||location.href;return"#"+url.replace(/^[^#]*#?(.*)$/,"$1")}$.fn[str_hashchange]=function(fn){return fn?this.bind(str_hashchange,fn):this.trigger(str_hashchange)};$.fn[str_hashchange].delay=50;special[str_hashchange]=$.extend(special[str_hashchange],
{setup:function(){if(supports_onhashchange)return false;$(fake_onhashchange.start)},teardown:function(){if(supports_onhashchange)return false;$(fake_onhashchange.stop)}});fake_onhashchange=function(){var self={},timeout_id,last_hash=get_fragment(),fn_retval=function(val){return val},history_set=fn_retval,history_get=fn_retval;self.start=function(){timeout_id||poll()};self.stop=function(){timeout_id&&clearTimeout(timeout_id);timeout_id=undefined};function poll(){var hash=get_fragment(),history_hash=
history_get(last_hash);if(hash!==last_hash){history_set(last_hash=hash,history_hash);$(window).trigger(str_hashchange)}else if(history_hash!==last_hash)location.href=location.href.replace(/#.*/,"")+history_hash;timeout_id=setTimeout(poll,$.fn[str_hashchange].delay)}$.browser.msie&&!supports_onhashchange&&function(){var iframe,iframe_src;self.start=function(){if(!iframe){iframe_src=$.fn[str_hashchange].src;iframe_src=iframe_src&&iframe_src+get_fragment();iframe=$('<iframe tabindex="-1" title="empty"/>').hide().one("load",
function(){iframe_src||history_set(get_fragment());poll()}).attr("src",iframe_src||"javascript:0").insertAfter("body")[0].contentWindow;doc.onpropertychange=function(){try{if(event.propertyName==="title")iframe.document.title=doc.title}catch(e){}}}};self.stop=fn_retval;history_get=function(){return get_fragment(iframe.location.href)};history_set=function(hash,history_hash){var iframe_doc=iframe.document,domain=$.fn[str_hashchange].domain;if(hash!==history_hash){iframe_doc.title=doc.title;iframe_doc.open();
domain&&iframe_doc.write('<script>document.domain="'+domain+'"<\/script>');iframe_doc.close();iframe.location.hash=hash}}}();return self}()})(jQuery,this);
(function($,undefined){$.widget("mobile.page",$.mobile.widget,{options:{backBtnText:"Back",addBackBtn:false,backBtnTheme:null,degradeInputs:{color:false,date:false,datetime:false,"datetime-local":false,email:false,month:false,number:false,range:"number",search:true,tel:false,time:false,url:false,week:false},keepNative:null},_create:function(){var $elem=this.element,o=this.options;this.keepNative=":jqmData(role='none'), :jqmData(role='nojs')"+(o.keepNative?", "+o.keepNative:"");if(this._trigger("beforeCreate")===
false)return;$elem.find(":jqmData(role='page'), :jqmData(role='content')").andSelf().each(function(){$(this).addClass("ui-"+$(this).jqmData("role"))});$elem.find(":jqmData(role='nojs')").addClass("ui-nojs");var $dataEls=$elem.find(":jqmData(role)").andSelf().each(function(){var $this=$(this),role=$this.jqmData("role"),theme=$this.jqmData("theme");if(role==="header"||role==="footer"){$this.addClass("ui-bar-"+(theme||$this.parent(":jqmData(role='page')").jqmData("theme")||"a"));$this.attr("role",role===
"header"?"banner":"contentinfo");var $headeranchors=$this.children("a"),leftbtn=$headeranchors.hasClass("ui-btn-left"),rightbtn=$headeranchors.hasClass("ui-btn-right");if(!leftbtn)leftbtn=$headeranchors.eq(0).not(".ui-btn-right").addClass("ui-btn-left").length;if(!rightbtn)rightbtn=$headeranchors.eq(1).addClass("ui-btn-right").length;if(o.addBackBtn&&role==="header"&&$(".ui-page").length>1&&$elem.jqmData("url")!==$.mobile.path.stripHash(location.hash)&&!leftbtn&&$this.jqmData("backbtn")!==false){var backBtn=
$("<a href='#' class='ui-btn-left' data-"+$.mobile.ns+"rel='back' data-"+$.mobile.ns+"icon='arrow-l'>"+o.backBtnText+"</a>").prependTo($this);if(o.backBtnTheme)backBtn.attr("data-"+$.mobile.ns+"theme",o.backBtnTheme)}$this.children("h1, h2, h3, h4, h5, h6").addClass("ui-title").attr({"tabindex":"0","role":"heading","aria-level":"1"})}else if(role==="content"){if(theme)$this.addClass("ui-body-"+theme);$this.attr("role","main")}else if(role==="page")$this.addClass("ui-body-"+(theme||"c"));switch(role){case "header":case "footer":case "page":case "content":$this.addClass("ui-"+
role);break;case "collapsible":case "fieldcontain":case "navbar":case "listview":case "dialog":$this[role]();break}});this._enhanceControls();$elem.find(":jqmData(role='button'), .ui-bar > a, .ui-header > a, .ui-footer > a").not(".ui-btn").not(this.keepNative).buttonMarkup();$elem.find(":jqmData(role='controlgroup')").controlgroup();$elem.find("a:not(.ui-btn):not(.ui-link-inherit)").not(this.keepNative).addClass("ui-link");$elem.fixHeaderFooter()},_typeAttributeRegex:/\s+type=["']?\w+['"]?/,_enhanceControls:function(){var o=
this.options,self=this;this.element.find("input").not(this.keepNative).each(function(){var type=this.getAttribute("type"),optType=o.degradeInputs[type]||"text";if(o.degradeInputs[type])$(this).replaceWith($("<div>").html($(this).clone()).html().replace(self._typeAttributeRegex,' type="'+optType+'" data-'+$.mobile.ns+'type="'+type+'" '))});var allControls=this.element.find("input, textarea, select, button"),nonNativeControls=allControls.not(this.keepNative);var textInputs=allControls.filter("input[type=text]");
if(textInputs.length&&typeof textInputs[0].autocorrect!=="undefined")textInputs.each(function(){this.setAttribute("autocorrect","off");this.setAttribute("autocomplete","off")});nonNativeControls.filter("[type='radio'], [type='checkbox']").checkboxradio();nonNativeControls.filter("button, [type='button'], [type='submit'], [type='reset'], [type='image']").button();nonNativeControls.filter("input, textarea").not("[type='radio'], [type='checkbox'], [type='button'], [type='submit'], [type='reset'], [type='image'], [type='hidden']").textinput();
nonNativeControls.filter("input, select").filter(":jqmData(role='slider'), :jqmData(type='range')").slider();nonNativeControls.filter("select:not(:jqmData(role='slider'))").selectmenu()}})})(jQuery);
(function($,window,undefined){$.extend($.mobile,{ns:"",subPageUrlKey:"ui-page",nonHistorySelectors:"dialog",activePageClass:"ui-page-active",activeBtnClass:"ui-btn-active",ajaxEnabled:true,useFastClick:true,hashListeningEnabled:true,defaultPageTransition:"slide",minScrollBack:screen.height/2,defaultDialogTransition:"pop",loadingMessage:"loading",pageLoadErrorMessage:"Error Loading Page",gradeA:function(){return $.support.mediaquery||$.mobile.browser.ie&&$.mobile.browser.ie>=7},keyCode:{ALT:18,BACKSPACE:8,
CAPS_LOCK:20,COMMA:188,COMMAND:91,COMMAND_LEFT:91,COMMAND_RIGHT:93,CONTROL:17,DELETE:46,DOWN:40,END:35,ENTER:13,ESCAPE:27,HOME:36,INSERT:45,LEFT:37,MENU:93,NUMPAD_ADD:107,NUMPAD_DECIMAL:110,NUMPAD_DIVIDE:111,NUMPAD_ENTER:108,NUMPAD_MULTIPLY:106,NUMPAD_SUBTRACT:109,PAGE_DOWN:34,PAGE_UP:33,PERIOD:190,RIGHT:39,SHIFT:16,SPACE:32,TAB:9,UP:38,WINDOWS:91},silentScroll:function(ypos){if($.type(ypos)!=="number")ypos=$.mobile.defaultHomeScroll;$.event.special.scrollstart.enabled=false;setTimeout(function(){window.scrollTo(0,
ypos);$(document).trigger("silentscroll",{x:0,y:ypos})},20);setTimeout(function(){$.event.special.scrollstart.enabled=true},150)},normalizeRegex:/-([a-z])/g,nsNormalize:function(prop){if(!prop)return;return $.camelCase($.mobile.ns+prop)}});$.fn.jqmData=function(prop,value){return this.data(prop?$.mobile.nsNormalize(prop):prop,value)};$.jqmData=function(elem,prop,value){return $.data(elem,$.mobile.nsNormalize(prop),value)};$.fn.jqmRemoveData=function(prop){return this.removeData($.mobile.nsNormalize(prop))};
$.jqmRemoveData=function(elem,prop){return $.removeData(elem,$.mobile.nsNormalize(prop))};$.jqmHasData=function(elem,prop){return $.hasData(elem,$.mobile.nsNormalize(prop))};var oldFind=$.find;$.find=function(selector,context,ret,extra){selector=selector.replace(/:jqmData\(([^)]*)\)/g,"[data-"+($.mobile.ns||"")+"$1]");return oldFind.call(this,selector,context,ret,extra)};$.extend($.find,oldFind);$.find.matches=function(expr,set){return $.find(expr,null,null,set)};$.find.matchesSelector=function(node,
expr){return $.find(expr,null,null,[node]).length>0}})(jQuery,this);
(function($,undefined){var $window=$(window),$html=$("html"),$head=$("head"),path={urlParseRE:/^(((([^:\/#\?]+:)?(?:\/\/((?:(([^:@\/#\?]+)(?:\:([^:@\/#\?]+))?)@)?(([^:\/#\?]+)(?:\:([0-9]+))?))?)?)?((\/?(?:[^\/\?#]+\/+)*)([^\?#]*)))?(\?[^#]+)?)(#.*)?/,parseUrl:function(url){if(typeof url==="object")return url;var u=url||"",matches=path.urlParseRE.exec(url),results;if(matches)results={href:matches[0]||"",hrefNoHash:matches[1]||"",hrefNoSearch:matches[2]||"",domain:matches[3]||"",protocol:matches[4]||
"",authority:matches[5]||"",username:matches[7]||"",password:matches[8]||"",host:matches[9]||"",hostname:matches[10]||"",port:matches[11]||"",pathname:matches[12]||"",directory:matches[13]||"",filename:matches[14]||"",search:matches[15]||"",hash:matches[16]||""};return results||{}},makePathAbsolute:function(relPath,absPath){if(relPath&&relPath.charAt(0)==="/")return relPath;relPath=relPath||"";absPath=absPath?absPath.replace(/^\/|\/?[^\/]*$/g,""):"";var absStack=absPath?absPath.split("/"):[],relStack=
relPath.split("/");for(var i=0;i<relStack.length;i++){var d=relStack[i];switch(d){case ".":break;case "..":if(absStack.length)absStack.pop();break;default:absStack.push(d);break}}return"/"+absStack.join("/")},isSameDomain:function(absUrl1,absUrl2){return path.parseUrl(absUrl1).domain===path.parseUrl(absUrl2).domain},isRelativeUrl:function(url){return path.parseUrl(url).protocol===""},isAbsoluteUrl:function(url){return path.parseUrl(url).protocol!==""},makeUrlAbsolute:function(relUrl,absUrl){if(!path.isRelativeUrl(relUrl))return relUrl;
var relObj=path.parseUrl(relUrl),absObj=path.parseUrl(absUrl),protocol=relObj.protocol||absObj.protocol,authority=relObj.authority||absObj.authority,hasPath=relObj.pathname!=="",pathname=path.makePathAbsolute(relObj.pathname||absObj.filename,absObj.pathname),search=relObj.search||!hasPath&&absObj.search||"",hash=relObj.hash;return protocol+"//"+authority+pathname+search+hash},addSearchParams:function(url,params){var u=path.parseUrl(url),p=typeof params==="object"?$.param(params):params,s=u.search||
"?";return u.hrefNoSearch+s+(s.charAt(s.length-1)!=="?"?"&":"")+p+(u.hash||"")},convertUrlToDataUrl:function(absUrl){var u=path.parseUrl(absUrl);if(path.isEmbeddedPage(u))return u.hash.replace(/^#/,"");else if(path.isSameDomain(u,documentBase))return u.hrefNoHash.replace(documentBase.domain,"");return absUrl},get:function(newPath){if(newPath===undefined)newPath=location.hash;return path.stripHash(newPath).replace(/[^\/]*\.[^\/*]+$/,"")},getFilePath:function(path){var splitkey="&"+$.mobile.subPageUrlKey;
return path&&path.split(splitkey)[0].split(dialogHashKey)[0]},set:function(path){location.hash=path},isPath:function(url){return/\//.test(url)},clean:function(url){return url.replace(documentBase.domain,"")},stripHash:function(url){return url.replace(/^#/,"")},cleanHash:function(hash){return path.stripHash(hash.replace(/\?.*$/,"").replace(dialogHashKey,""))},isExternal:function(url){var u=path.parseUrl(url);return u.protocol&&u.domain!==documentUrl.domain?true:false},hasProtocol:function(url){return/^(:?\w+:)/.test(url)},
isEmbeddedPage:function(url){var u=path.parseUrl(url);if(u.protocol!=="")return u.hash&&(u.hrefNoHash===documentUrl.hrefNoHash||documentBaseDiffers&&u.hrefNoHash===documentBase.hrefNoHash);return/^#/.test(u.href)}},$activeClickedLink=null,urlHistory={stack:[],activeIndex:0,getActive:function(){return urlHistory.stack[urlHistory.activeIndex]},getPrev:function(){return urlHistory.stack[urlHistory.activeIndex-1]},getNext:function(){return urlHistory.stack[urlHistory.activeIndex+1]},addNew:function(url,
transition,title,storedTo){if(urlHistory.getNext())urlHistory.clearForward();urlHistory.stack.push({url:url,transition:transition,title:title,page:storedTo});urlHistory.activeIndex=urlHistory.stack.length-1},clearForward:function(){urlHistory.stack=urlHistory.stack.slice(0,urlHistory.activeIndex+1)},directHashChange:function(opts){var back,forward,newActiveIndex;$.each(urlHistory.stack,function(i,historyEntry){if(opts.currentUrl===historyEntry.url){back=i<urlHistory.activeIndex;forward=!back;newActiveIndex=
i}});this.activeIndex=newActiveIndex!==undefined?newActiveIndex:this.activeIndex;if(back)opts.isBack();else if(forward)opts.isForward()},ignoreNextHashChange:false},focusable="[tabindex],a,button:visible,select:visible,input",pageTransitionQueue=[],isPageTransitioning=false,dialogHashKey="&ui-state=dialog",$base=$head.children("base"),documentUrl=path.parseUrl(location.href),documentBase=$base.length?path.parseUrl(path.makeUrlAbsolute($base.attr("href"),documentUrl.href)):documentUrl,documentBaseDiffers=
documentUrl.hrefNoHash!==documentBase.hrefNoHash;var base=$.support.dynamicBaseTag?{element:$base.length?$base:$("<base>",{href:documentBase.hrefNoHash}).prependTo($head),set:function(href){base.element.attr("href",path.makeUrlAbsolute(href,documentBase))},reset:function(){base.element.attr("href",documentBase.hrefNoHash)}}:undefined;function reFocus(page){var lastClicked=page.jqmData("lastClicked");if(lastClicked&&lastClicked.length)lastClicked.focus();else{var pageTitle=page.find(".ui-title:eq(0)");
if(pageTitle.length)pageTitle.focus();else page.find(focusable).eq(0).focus()}}function removeActiveLinkClass(forceRemoval){if(!!$activeClickedLink&&(!$activeClickedLink.closest(".ui-page-active").length||forceRemoval))$activeClickedLink.removeClass($.mobile.activeBtnClass);$activeClickedLink=null}function releasePageTransitionLock(){isPageTransitioning=false;if(pageTransitionQueue.length>0)$.mobile.changePage.apply(null,pageTransitionQueue.pop())}function transitionPages(toPage,fromPage,transition,
reverse){var currScroll=$.support.scrollTop?$window.scrollTop():true,toScroll=toPage.data("lastScroll")||$.mobile.defaultHomeScroll,screenHeight=getScreenHeight();if(currScroll)window.scrollTo(0,$.mobile.defaultHomeScroll);if(toScroll<$.mobile.minScrollBack)toScroll=0;if(fromPage){fromPage.height(screenHeight+currScroll).jqmData("lastScroll",currScroll).jqmData("lastClicked",$activeClickedLink);fromPage.data("page")._trigger("beforehide",null,{nextPage:toPage})}toPage.height(screenHeight+toScroll).data("page")._trigger("beforeshow",
null,{prevPage:fromPage||$("")});$.mobile.hidePageLoadingMsg();var th=$.mobile.transitionHandlers[transition||"none"]||$.mobile.defaultTransitionHandler,promise=th(transition,reverse,toPage,fromPage);promise.done(function(){toPage.height("");if(toScroll){$.mobile.silentScroll(toScroll);$(document).one("silentscroll",function(){reFocus(toPage)})}else reFocus(toPage);if(fromPage)fromPage.height("").data("page")._trigger("hide",null,{nextPage:toPage});toPage.data("page")._trigger("show",null,{prevPage:fromPage||
$("")})});return promise}function getScreenHeight(){var orientation=jQuery.event.special.orientationchange.orientation(),port=orientation==="portrait",winMin=port?480:320,screenHeight=port?screen.availHeight:screen.availWidth,winHeight=Math.max(winMin,$(window).height()),pageMin=Math.min(screenHeight,winHeight);return pageMin}function resetActivePageHeight(){$("."+$.mobile.activePageClass).css("min-height",getScreenHeight())}function enhancePage($page,role){if(role)$page.attr("data-"+$.mobile.ns+
"role",role);$page.page()}$.fn.animationComplete=function(callback){if($.support.cssTransitions)return $(this).one("webkitAnimationEnd",callback);else{setTimeout(callback,0);return $(this)}};$.mobile.updateHash=path.set;$.mobile.path=path;$.mobile.base=base;$.mobile.urlstack=urlHistory.stack;$.mobile.urlHistory=urlHistory;$.mobile.noneTransitionHandler=function(name,reverse,$toPage,$fromPage){if($fromPage)$fromPage.removeClass($.mobile.activePageClass);$toPage.addClass($.mobile.activePageClass);return $.Deferred().resolve(name,
reverse,$toPage,$fromPage).promise()};$.mobile.defaultTransitionHandler=$.mobile.noneTransitionHandler;$.mobile.transitionHandlers={none:$.mobile.defaultTransitionHandler};$.mobile.allowCrossDomainPages=false;$.mobile.getDocumentUrl=function(asParsedObject){return asParsedObject?$.extend({},documentUrl):documentUrl.href};$.mobile.getDocumentBase=function(asParsedObject){return asParsedObject?$.extend({},documentBase):documentBase.href};$.mobile.loadPage=function(url,options){var deferred=$.Deferred(),
settings=$.extend({},$.mobile.loadPage.defaults,options),page=null,dupCachedPage=null,absUrl=path.makeUrlAbsolute(url,documentBase.hrefNoHash);if(settings.data&&settings.type==="get"){absUrl=path.addSearchParams(absUrl,settings.data);settings.data=undefined}var fileUrl=path.getFilePath(absUrl),dataUrl=path.convertUrlToDataUrl(absUrl);settings.pageContainer=settings.pageContainer||$.mobile.pageContainer;page=settings.pageContainer.children(":jqmData(url='"+dataUrl+"')");if(base)base.reset();if(page.length){if(!settings.reloadPage){enhancePage(page,
settings.role);deferred.resolve(absUrl,options,page);return deferred.promise()}dupCachedPage=page}if(settings.showLoadMsg)$.mobile.showPageLoadingMsg();$.ajax({url:fileUrl,type:settings.type,data:settings.data,dataType:"html",success:function(html){var all=$("<div></div>"),newPageTitle=html.match(/<title[^>]*>([^<]*)/)&&RegExp.$1,pageElemRegex=new RegExp(".*(<[^>]+\\bdata-"+$.mobile.ns+"role=[\"']?page[\"']?[^>]*>).*"),dataUrlRegex=new RegExp("\\bdata-"+$.mobile.ns+"url=[\"']?([^\"'>]*)[\"']?");if(pageElemRegex.test(html)&&
RegExp.$1&&dataUrlRegex.test(RegExp.$1)&&RegExp.$1)url=fileUrl=path.getFilePath(RegExp.$1);if(base)base.set(fileUrl);all.get(0).innerHTML=html;page=all.find(":jqmData(role='page'), :jqmData(role='dialog')").first();if(newPageTitle&&!page.jqmData("title"))page.jqmData("title",newPageTitle);if(!$.support.dynamicBaseTag){var newPath=path.get(fileUrl);page.find("[src], link[href], a[rel='external'], :jqmData(ajax='false'), a[target]").each(function(){var thisAttr=$(this).is("[href]")?"href":$(this).is("[src]")?
"src":"action",thisUrl=$(this).attr(thisAttr);thisUrl=thisUrl.replace(location.protocol+"//"+location.host+location.pathname,"");if(!/^(\w+:|#|\/)/.test(thisUrl))$(this).attr(thisAttr,newPath+thisUrl)})}page.attr("data-"+$.mobile.ns+"url",path.convertUrlToDataUrl(fileUrl)).appendTo(settings.pageContainer);enhancePage(page,settings.role);if(absUrl.indexOf("&"+$.mobile.subPageUrlKey)>-1)page=settings.pageContainer.children(":jqmData(url='"+dataUrl+"')");if(settings.showLoadMsg)$.mobile.hidePageLoadingMsg();
deferred.resolve(absUrl,options,page,dupCachedPage)},error:function(){if(base)base.set(path.get());if(settings.showLoadMsg){$.mobile.hidePageLoadingMsg();$("<div class='ui-loader ui-overlay-shadow ui-body-e ui-corner-all'><h1>"+$.mobile.pageLoadErrorMessage+"</h1></div>").css({"display":"block","opacity":0.96,"top":$window.scrollTop()+100}).appendTo(settings.pageContainer).delay(800).fadeOut(400,function(){$(this).remove()})}deferred.reject(absUrl,options)}});return deferred.promise()};$.mobile.loadPage.defaults=
{type:"get",data:undefined,reloadPage:false,role:undefined,showLoadMsg:true,pageContainer:undefined};$.mobile.changePage=function(toPage,options){if(typeof options!=="object"){var opts=null;if(typeof toPage==="object"&&toPage.url&&toPage.type){opts={type:toPage.type,data:toPage.data,forcePageLoad:true};toPage=toPage.url}var len=arguments.length;if(len>1){var argNames=["transition","reverse","changeHash","fromHashChange"],i;for(i=1;i<len;i++){var a=arguments[i];if(typeof a!=="undefined"){opts=opts||
{};opts[argNames[i-1]]=a}}}if(opts)return $.mobile.changePage(toPage,opts)}if(isPageTransitioning){pageTransitionQueue.unshift(arguments);return}isPageTransitioning=true;var settings=$.extend({},$.mobile.changePage.defaults,options);settings.pageContainer=settings.pageContainer||$.mobile.pageContainer;if(typeof toPage=="string"){$.mobile.loadPage(toPage,settings).done(function(url,options,newPage,dupCachedPage){isPageTransitioning=false;options.duplicateCachedPage=dupCachedPage;$.mobile.changePage(newPage,
options)}).fail(function(url,options){isPageTransitioning=false;removeActiveLinkClass(true);releasePageTransitionLock();settings.pageContainer.trigger("changepagefailed")});return}var mpc=settings.pageContainer,fromPage=$.mobile.activePage,url=toPage.jqmData("url"),fileUrl=path.getFilePath(url),active=urlHistory.getActive(),activeIsInitialPage=urlHistory.activeIndex===0,historyDir=0,pageTitle=document.title,isDialog=settings.role==="dialog"||toPage.jqmData("role")==="dialog";mpc.trigger("beforechangepage");
if(fromPage&&fromPage[0]===toPage[0]){isPageTransitioning=false;mpc.trigger("changepage");return}enhancePage(toPage,settings.role);if(settings.fromHashChange)urlHistory.directHashChange({currentUrl:url,isBack:function(){historyDir=-1},isForward:function(){historyDir=1}});$(document.activeElement||"").add("input:focus, textarea:focus, select:focus").blur();if(isDialog&&active)url=active.url+dialogHashKey;if(settings.changeHash!==false&&url){urlHistory.ignoreNextHashChange=true;path.set(url)}var newPageTitle=
toPage.jqmData("title")||toPage.children(":jqmData(role='header')").find(".ui-title").text();if(!!newPageTitle&&pageTitle==document.title)pageTitle=newPageTitle;if(!historyDir)urlHistory.addNew(url,settings.transition,pageTitle,toPage);document.title=urlHistory.getActive().title;$.mobile.activePage=toPage;settings.transition=settings.transition||(historyDir&&!activeIsInitialPage?active.transition:undefined)||(settings.role==="dialog"?$.mobile.defaultDialogTransition:$.mobile.defaultPageTransition);
settings.reverse=settings.reverse||historyDir<0;transitionPages(toPage,fromPage,settings.transition,settings.reverse).done(function(){removeActiveLinkClass();if(settings.duplicateCachedPage)settings.duplicateCachedPage.remove();$html.removeClass("ui-mobile-rendering");releasePageTransitionLock();mpc.trigger("changepage")})};$.mobile.changePage.defaults={transition:undefined,reverse:false,changeHash:true,fromHashChange:false,role:undefined,duplicateCachedPage:undefined,pageContainer:undefined};$("form").live("submit",
function(event){var $this=$(this);if(!$.mobile.ajaxEnabled||$this.is(":jqmData(ajax='false')"))return;var type=$this.attr("method"),url=path.makeUrlAbsolute($this.attr("action"),getClosestBaseUrl($this)),target=$this.attr("target");if(path.isExternal(url)||target)return;$.mobile.changePage(url,{type:type.length&&type.toLowerCase()||"get",data:$this.serialize(),transition:$this.jqmData("transition"),direction:$this.jqmData("direction"),reloadPage:true});event.preventDefault()});function findClosestLink(ele){while(ele){if(ele.nodeName.toLowerCase()==
"a")break;ele=ele.parentNode}return ele}function getClosestBaseUrl(ele){var url=$(ele).closest(".ui-page").jqmData("url"),base=documentBase.hrefNoHash;if(!url||!path.isPath(url))url=base;return path.makeUrlAbsolute(url,base)}$(document).bind("vclick",function(event){var link=findClosestLink(event.target);if(link)if(path.parseUrl(link.getAttribute("href")||"#").hash!=="#"){$(link).closest(".ui-btn").not(".ui-disabled").addClass($.mobile.activeBtnClass);$("."+$.mobile.activePageClass+" .ui-btn").not(link).blur()}});
$(document).bind($.mobile.useFastClick?"vclick click":"click",function(event){var link=findClosestLink(event.target);if(!link)return;var $link=$(link),httpCleanup=function(){window.setTimeout(function(){removeActiveLinkClass(true)},200)};if($link.is(":jqmData(rel='back')")){window.history.back();return false}if(!$.mobile.ajaxEnabled){httpCleanup();return}var baseUrl=getClosestBaseUrl($link),href=path.makeUrlAbsolute($link.attr("href")||"#",baseUrl);if(href.search("#")!=-1){href=href.replace(/[^#]*#/,
"");if(!href){event.preventDefault();return}else if(path.isPath(href))href=path.makeUrlAbsolute(href,baseUrl);else href=path.makeUrlAbsolute("#"+href,documentUrl.hrefNoHash)}var useDefaultUrlHandling=$link.is("[rel='external']")||$link.is(":jqmData(ajax='false')")||$link.is("[target]"),isCrossDomainPageLoad=$.mobile.allowCrossDomainPages&&documentUrl.protocol==="file:"&&href.search(/^https?:/)!=-1,isExternal=useDefaultUrlHandling||path.isExternal(href)&&!isCrossDomainPageLoad;$activeClickedLink=$link.closest(".ui-btn");
if(isExternal){httpCleanup();return}var transition=$link.jqmData("transition"),direction=$link.jqmData("direction"),reverse=direction&&direction==="reverse"||$link.jqmData("back"),role=$link.attr("data-"+$.mobile.ns+"rel")||undefined;$.mobile.changePage(href,{transition:transition,reverse:reverse,role:role});event.preventDefault()});$window.bind("hashchange",function(e,triggered){var to=path.stripHash(location.hash),transition=$.mobile.urlHistory.stack.length===0?"none":undefined;if(!$.mobile.hashListeningEnabled||
urlHistory.ignoreNextHashChange){urlHistory.ignoreNextHashChange=false;return}if(urlHistory.stack.length>1&&to.indexOf(dialogHashKey)>-1)if(!$.mobile.activePage.is(".ui-dialog")){urlHistory.directHashChange({currentUrl:to,isBack:function(){window.history.back()},isForward:function(){window.history.forward()}});return}else{var setTo=function(){to=$.mobile.urlHistory.getActive().page};urlHistory.directHashChange({currentUrl:to,isBack:setTo,isForward:setTo})}if(to){to=typeof to==="string"&&!path.isPath(to)?
"#"+to:to;$.mobile.changePage(to,{transition:transition,changeHash:false,fromHashChange:true})}else $.mobile.changePage($.mobile.firstPage,{transition:transition,changeHash:false,fromHashChange:true})});$(document).bind("pageshow",resetActivePageHeight);$(window).bind("throttledresize",resetActivePageHeight)})(jQuery);
(function($,window,undefined){function css3TransitionHandler(name,reverse,$to,$from){var deferred=new $.Deferred,reverseClass=reverse?" reverse":"",viewportClass="ui-mobile-viewport-transitioning viewport-"+name,doneFunc=function(){$to.add($from).removeClass("out in reverse "+name);if($from)$from.removeClass($.mobile.activePageClass);$to.parent().removeClass(viewportClass);deferred.resolve(name,reverse,$to,$from)};$to.animationComplete(doneFunc);$to.parent().addClass(viewportClass);if($from)$from.addClass(name+
" out"+reverseClass);$to.addClass($.mobile.activePageClass+" "+name+" in"+reverseClass);return deferred.promise()}$.mobile.css3TransitionHandler=css3TransitionHandler;if($.mobile.defaultTransitionHandler===$.mobile.noneTransitionHandler)$.mobile.defaultTransitionHandler=css3TransitionHandler})(jQuery,this);
(function($,undefined){$.fn.fixHeaderFooter=function(options){if(!$.support.scrollTop)return this;return this.each(function(){var $this=$(this);if($this.jqmData("fullscreen"))$this.addClass("ui-page-fullscreen");$this.find(".ui-header:jqmData(position='fixed')").addClass("ui-header-fixed ui-fixed-inline fade");$this.find(".ui-footer:jqmData(position='fixed')").addClass("ui-footer-fixed ui-fixed-inline fade")})};$.fixedToolbars=function(){if(!$.support.scrollTop)return;var currentstate="inline",autoHideMode=
false,showDelay=100,delayTimer,ignoreTargets="a,input,textarea,select,button,label,.ui-header-fixed,.ui-footer-fixed",toolbarSelector=".ui-header-fixed:first, .ui-footer-fixed:not(.ui-footer-duplicate):last",stickyFooter,supportTouch=$.support.touch,touchStartEvent=supportTouch?"touchstart":"mousedown",touchStopEvent=supportTouch?"touchend":"mouseup",stateBefore=null,scrollTriggered=false,touchToggleEnabled=true;function showEventCallback(event){if(!autoHideMode&&currentstate=="overlay"){if(!delayTimer)$.fixedToolbars.hide(true);
$.fixedToolbars.startShowTimer()}}$(function(){$(document).bind("vmousedown",function(event){if(touchToggleEnabled)stateBefore=currentstate}).bind("vclick",function(event){if(touchToggleEnabled){if($(event.target).closest(ignoreTargets).length)return;if(!scrollTriggered){$.fixedToolbars.toggle(stateBefore);stateBefore=null}}}).bind("silentscroll",showEventCallback);($(document).scrollTop()==0?$(window):$(document)).bind("scrollstart",function(event){scrollTriggered=true;if(stateBefore==null)stateBefore=
currentstate;var isOverlayState=stateBefore=="overlay";autoHideMode=isOverlayState||!!delayTimer;if(autoHideMode){$.fixedToolbars.clearShowTimer();if(isOverlayState)$.fixedToolbars.hide(true)}}).bind("scrollstop",function(event){if($(event.target).closest(ignoreTargets).length)return;scrollTriggered=false;if(autoHideMode){autoHideMode=false;$.fixedToolbars.startShowTimer()}stateBefore=null});$(window).bind("resize",showEventCallback)});$(".ui-page").live("pagebeforeshow",function(event,ui){var page=
$(event.target),footer=page.find(":jqmData(role='footer')"),id=footer.data("id"),prevPage=ui.prevPage,prevFooter=prevPage&&prevPage.find(":jqmData(role='footer')"),prevFooterMatches=prevFooter.length&&prevFooter.jqmData("id")===id;if(id&&prevFooterMatches){stickyFooter=footer;setTop(stickyFooter.removeClass("fade in out").appendTo($.mobile.pageContainer))}});$(".ui-page").live("pageshow",function(event,ui){var $this=$(this);if(stickyFooter&&stickyFooter.length)setTimeout(function(){setTop(stickyFooter.appendTo($this).addClass("fade"));
stickyFooter=null},500);$.fixedToolbars.show(true,this)});$(".ui-collapsible-contain").live("collapse expand",showEventCallback);function getOffsetTop(ele){var top=0;if(ele){var op=ele.offsetParent,body=document.body;top=ele.offsetTop;while(ele&&ele!=body){top+=ele.scrollTop||0;if(ele==op){top+=op.offsetTop;op=ele.offsetParent}ele=ele.parentNode}}return top}function setTop(el){var fromTop=$(window).scrollTop(),thisTop=getOffsetTop(el[0]),thisCSStop=el.css("top")=="auto"?0:parseFloat(el.css("top")),
screenHeight=window.innerHeight,thisHeight=el.outerHeight(),useRelative=el.parents(".ui-page:not(.ui-page-fullscreen)").length,relval;if(el.is(".ui-header-fixed")){relval=fromTop-thisTop+thisCSStop;if(relval<thisTop)relval=0;return el.css("top",useRelative?relval:fromTop)}else{relval=fromTop+screenHeight-thisHeight-(thisTop-thisCSStop);return el.css("top",useRelative?relval:fromTop+screenHeight-thisHeight)}}return{show:function(immediately,page){$.fixedToolbars.clearShowTimer();currentstate="overlay";
var $ap=page?$(page):$.mobile.activePage?$.mobile.activePage:$(".ui-page-active");return $ap.children(toolbarSelector).each(function(){var el=$(this),fromTop=$(window).scrollTop(),thisTop=getOffsetTop(el[0]),screenHeight=window.innerHeight,thisHeight=el.outerHeight(),alreadyVisible=el.is(".ui-header-fixed")&&fromTop<=thisTop+thisHeight||el.is(".ui-footer-fixed")&&thisTop<=fromTop+screenHeight;el.addClass("ui-fixed-overlay").removeClass("ui-fixed-inline");if(!alreadyVisible&&!immediately)el.animationComplete(function(){el.removeClass("in")}).addClass("in");
setTop(el)})},hide:function(immediately){currentstate="inline";var $ap=$.mobile.activePage?$.mobile.activePage:$(".ui-page-active");return $ap.children(toolbarSelector).each(function(){var el=$(this);var thisCSStop=el.css("top");thisCSStop=thisCSStop=="auto"?0:parseFloat(thisCSStop);el.addClass("ui-fixed-inline").removeClass("ui-fixed-overlay");if(thisCSStop<0||el.is(".ui-header-fixed")&&thisCSStop!=0)if(immediately)el.css("top",0);else if(el.css("top")!=="auto"&&parseFloat(el.css("top"))!==0){var classes=
"out reverse";el.animationComplete(function(){el.removeClass(classes);el.css("top",0)}).addClass(classes)}})},startShowTimer:function(){$.fixedToolbars.clearShowTimer();var args=$.makeArray(arguments);delayTimer=setTimeout(function(){delayTimer=undefined;$.fixedToolbars.show.apply(null,args)},showDelay)},clearShowTimer:function(){if(delayTimer)clearTimeout(delayTimer);delayTimer=undefined},toggle:function(from){if(from)currentstate=from;return currentstate=="overlay"?$.fixedToolbars.hide():$.fixedToolbars.show()},
setTouchToggleEnabled:function(enabled){touchToggleEnabled=enabled}}}()})(jQuery);
(function($,undefined){$.widget("mobile.checkboxradio",$.mobile.widget,{options:{theme:null},_create:function(){var self=this,input=this.element,label=input.closest("form,fieldset,:jqmData(role='page')").find("label").filter('[for="'+input[0].id+'"]'),inputtype=input.attr("type"),checkedicon="ui-icon-"+inputtype+"-on",uncheckedicon="ui-icon-"+inputtype+"-off";if(inputtype!="checkbox"&&inputtype!="radio")return;$.extend(this,{label:label,inputtype:inputtype,checkedicon:checkedicon,uncheckedicon:uncheckedicon});
if(!this.options.theme)this.options.theme=this.element.jqmData("theme");label.buttonMarkup({theme:this.options.theme,icon:this.element.parents(":jqmData(type='horizontal')").length?undefined:uncheckedicon,shadow:false});input.add(label).wrapAll("<div class='ui-"+inputtype+"'></div>");label.bind({vmouseover:function(){if($(this).parent().is(".ui-disabled"))return false},vclick:function(event){if(input.is(":disabled")){event.preventDefault();return}self._cacheVals();input.prop("checked",inputtype===
"radio"&&true||!input.prop("checked"));self._getInputSet().not(input).prop("checked",false);self._updateAll();return false}});input.bind({vmousedown:function(){this._cacheVals()},vclick:function(){if($(this).is(":checked")){$(this).prop("checked",true);self._getInputSet().not($(this)).prop("checked",false)}else $(this).prop("checked",false);self._updateAll()},focus:function(){label.addClass("ui-focus")},blur:function(){label.removeClass("ui-focus")}});this.refresh()},_cacheVals:function(){this._getInputSet().each(function(){$(this).jqmData("cacheVal",
$(this).is(":checked"))})},_getInputSet:function(){return this.element.closest("form,fieldset,:jqmData(role='page')").find("input[name='"+this.element.attr("name")+"'][type='"+this.inputtype+"']")},_updateAll:function(){var self=this;this._getInputSet().each(function(){if($(this).is(":checked")||self.inputtype==="checkbox")$(this).trigger("change")}).checkboxradio("refresh")},refresh:function(){var input=this.element,label=this.label,icon=label.find(".ui-icon");if($(input[0]).prop("checked")){label.addClass($.mobile.activeBtnClass);
icon.addClass(this.checkedicon).removeClass(this.uncheckedicon)}else{label.removeClass($.mobile.activeBtnClass);icon.removeClass(this.checkedicon).addClass(this.uncheckedicon)}if(input.is(":disabled"))this.disable();else this.enable()},disable:function(){this.element.prop("disabled",true).parent().addClass("ui-disabled")},enable:function(){this.element.prop("disabled",false).parent().removeClass("ui-disabled")}})})(jQuery);
(function($,undefined){$.widget("mobile.textinput",$.mobile.widget,{options:{theme:null},_create:function(){var input=this.element,o=this.options,theme=o.theme,themeclass;if(!theme)var themedParent=this.element.closest("[class*='ui-bar-'],[class*='ui-body-']"),themeLetter=themedParent.length&&/ui-(bar|body)-([a-z])/.exec(themedParent.attr("class")),theme=themeLetter&&themeLetter[2]||"c";themeclass=" ui-body-"+theme;$('label[for="'+input.attr("id")+'"]').addClass("ui-input-text");input.addClass("ui-input-text ui-body-"+
o.theme);var focusedEl=input;if(input.is("[type='search'],:jqmData(type='search')")){focusedEl=input.wrap('<div class="ui-input-search ui-shadow-inset ui-btn-corner-all ui-btn-shadow ui-icon-searchfield'+themeclass+'"></div>').parent();var clearbtn=$('<a href="#" class="ui-input-clear" title="clear text">clear text</a>').tap(function(e){input.val("").focus();input.trigger("change");clearbtn.addClass("ui-input-clear-hidden");e.preventDefault()}).appendTo(focusedEl).buttonMarkup({icon:"delete",iconpos:"notext",
corners:true,shadow:true});function toggleClear(){if(input.val()=="")clearbtn.addClass("ui-input-clear-hidden");else clearbtn.removeClass("ui-input-clear-hidden")}toggleClear();input.keyup(toggleClear);input.focus(toggleClear)}else input.addClass("ui-corner-all ui-shadow-inset"+themeclass);input.focus(function(){focusedEl.addClass("ui-focus")}).blur(function(){focusedEl.removeClass("ui-focus")});if(input.is("textarea")){var extraLineHeight=15,keyupTimeoutBuffer=100,keyup=function(){var scrollHeight=
input[0].scrollHeight,clientHeight=input[0].clientHeight;if(clientHeight<scrollHeight)input.css({height:scrollHeight+extraLineHeight})},keyupTimeout;input.keyup(function(){clearTimeout(keyupTimeout);keyupTimeout=setTimeout(keyup,keyupTimeoutBuffer)})}},disable:function(){(this.element.attr("disabled",true).is("[type='search'],:jqmData(type='search')")?this.element.parent():this.element).addClass("ui-disabled")},enable:function(){(this.element.attr("disabled",false).is("[type='search'],:jqmData(type='search')")?
this.element.parent():this.element).removeClass("ui-disabled")}})})(jQuery);
(function($,undefined){$.widget("mobile.selectmenu",$.mobile.widget,{options:{theme:null,disabled:false,icon:"arrow-d",iconpos:"right",inline:null,corners:true,shadow:true,iconshadow:true,menuPageTheme:"b",overlayTheme:"a",hidePlaceholderMenuItems:true,closeText:"Close",nativeMenu:true},_create:function(){var self=this,o=this.options,select=this.element.wrap("<div class='ui-select'>"),selectID=select.attr("id"),label=$('label[for="'+selectID+'"]').addClass("ui-select"),selectedIndex=select[0].selectedIndex==
-1?0:select[0].selectedIndex,button=(self.options.nativeMenu?$("<div/>"):$("<a>",{"href":"#","role":"button","id":buttonId,"aria-haspopup":"true","aria-owns":menuId})).text($(select[0].options.item(selectedIndex)).text()).insertBefore(select).buttonMarkup({theme:o.theme,icon:o.icon,iconpos:o.iconpos,inline:o.inline,corners:o.corners,shadow:o.shadow,iconshadow:o.iconshadow}),isMultiple=self.isMultiple=select[0].multiple;if(o.nativeMenu&&window.opera&&window.opera.version)select.addClass("ui-select-nativeonly");
if(!o.nativeMenu)var options=select.find("option"),buttonId=selectID+"-button",menuId=selectID+"-menu",thisPage=select.closest(".ui-page"),theme=/ui-btn-up-([a-z])/.exec(button.attr("class"))[1],menuPage=$("<div data-"+$.mobile.ns+"role='dialog' data-"+$.mobile.ns+"theme='"+o.menuPageTheme+"'>"+"<div data-"+$.mobile.ns+"role='header'>"+"<div class='ui-title'>"+label.text()+"</div>"+"</div>"+"<div data-"+$.mobile.ns+"role='content'></div>"+"</div>").appendTo($.mobile.pageContainer).page(),menuPageContent=
menuPage.find(".ui-content"),menuPageClose=menuPage.find(".ui-header a"),screen=$("<div>",{"class":"ui-selectmenu-screen ui-screen-hidden"}).appendTo(thisPage),listbox=$("<div>",{"class":"ui-selectmenu ui-selectmenu-hidden ui-overlay-shadow ui-corner-all pop ui-body-"+o.overlayTheme}).insertAfter(screen),list=$("<ul>",{"class":"ui-selectmenu-list","id":menuId,"role":"listbox","aria-labelledby":buttonId}).attr("data-"+$.mobile.ns+"theme",theme).appendTo(listbox),header=$("<div>",{"class":"ui-header ui-bar-"+
theme}).prependTo(listbox),headerTitle=$("<h1>",{"class":"ui-title"}).appendTo(header),headerClose=$("<a>",{"text":o.closeText,"href":"#","class":"ui-btn-left"}).attr("data-"+$.mobile.ns+"iconpos","notext").attr("data-"+$.mobile.ns+"icon","delete").appendTo(header).buttonMarkup(),menuType;if(isMultiple)self.buttonCount=$("<span>").addClass("ui-li-count ui-btn-up-c ui-btn-corner-all").hide().appendTo(button);if(o.disabled)this.disable();select.change(function(){self.refresh()});$.extend(self,{select:select,
optionElems:options,selectID:selectID,label:label,buttonId:buttonId,menuId:menuId,thisPage:thisPage,button:button,menuPage:menuPage,menuPageContent:menuPageContent,screen:screen,listbox:listbox,list:list,menuType:menuType,header:header,headerClose:headerClose,headerTitle:headerTitle,placeholder:""});if(o.nativeMenu)select.appendTo(button).bind("vmousedown",function(e){button.addClass($.mobile.activeBtnClass)}).bind("focus vmouseover",function(){button.trigger("vmouseover")}).bind("vmousemove",function(){button.removeClass($.mobile.activeBtnClass)}).bind("change blur vmouseout",
function(){button.trigger("vmouseout").removeClass($.mobile.activeBtnClass)});else{self.refresh();select.attr("tabindex","-1").focus(function(){$(this).blur();button.focus()});button.bind("vclick keydown",function(event){if(event.type=="vclick"||event.keyCode&&(event.keyCode===$.mobile.keyCode.ENTER||event.keyCode===$.mobile.keyCode.SPACE)){self.open();event.preventDefault()}});list.attr("role","listbox").delegate(".ui-li>a","focusin",function(){$(this).attr("tabindex","0")}).delegate(".ui-li>a",
"focusout",function(){$(this).attr("tabindex","-1")}).delegate("li:not(.ui-disabled, .ui-li-divider)","vclick",function(event){var oldIndex=select[0].selectedIndex,newIndex=list.find("li:not(.ui-li-divider)").index(this),option=self.optionElems.eq(newIndex)[0];option.selected=isMultiple?!option.selected:true;if(isMultiple)$(this).find(".ui-icon").toggleClass("ui-icon-checkbox-on",option.selected).toggleClass("ui-icon-checkbox-off",!option.selected);if(isMultiple||oldIndex!==newIndex)select.trigger("change");
if(!isMultiple)self.close();event.preventDefault()}).keydown(function(e){var target=$(e.target),li=target.closest("li");switch(e.keyCode){case 38:var prev=li.prev();if(prev.length){target.blur().attr("tabindex","-1");prev.find("a").first().focus()}return false;break;case 40:var next=li.next();if(next.length){target.blur().attr("tabindex","-1");next.find("a").first().focus()}return false;break;case 13:case 32:target.trigger("vclick");return false;break}});screen.bind("vclick",function(event){self.close()});
self.headerClose.click(function(){if(self.menuType=="overlay"){self.close();return false}})}},_buildList:function(){var self=this,o=this.options,placeholder=this.placeholder,optgroups=[],lis=[],dataIcon=self.isMultiple?"checkbox-off":"false";self.list.empty().filter(".ui-listview").listview("destroy");self.select.find("option").each(function(i){var $this=$(this),$parent=$this.parent(),text=$this.text(),anchor="<a href='#'>"+text+"</a>",classes=[],extraAttrs=[];if($parent.is("optgroup")){var optLabel=
$parent.attr("label");if($.inArray(optLabel,optgroups)===-1){lis.push("<li data-"+$.mobile.ns+"role='list-divider'>"+optLabel+"</li>");optgroups.push(optLabel)}}if(!this.getAttribute("value")||text.length==0||$this.jqmData("placeholder")){if(o.hidePlaceholderMenuItems)classes.push("ui-selectmenu-placeholder");placeholder=self.placeholder=text}if(this.disabled){classes.push("ui-disabled");extraAttrs.push("aria-disabled='true'")}lis.push("<li data-"+$.mobile.ns+"icon='"+dataIcon+"' class='"+classes.join(" ")+
"' "+extraAttrs.join(" ")+">"+anchor+"</li>")});self.list.html(lis.join(" "));self.list.find("li").attr({"role":"option","tabindex":"-1"}).first().attr("tabindex","0");if(!this.isMultiple)this.headerClose.hide();if(!this.isMultiple&&!placeholder.length)this.header.hide();else this.headerTitle.text(this.placeholder);self.list.listview()},refresh:function(forceRebuild){var self=this,select=this.element,isMultiple=this.isMultiple,options=this.optionElems=select.find("option"),selected=options.filter(":selected"),
indicies=selected.map(function(){return options.index(this)}).get();if(!self.options.nativeMenu&&(forceRebuild||select[0].options.length!=self.list.find("li").length))self._buildList();self.button.find(".ui-btn-text").text(function(){if(!isMultiple)return selected.text();return selected.length?selected.map(function(){return $(this).text()}).get().join(", "):self.placeholder});if(isMultiple)self.buttonCount[selected.length>1?"show":"hide"]().text(selected.length);if(!self.options.nativeMenu)self.list.find("li:not(.ui-li-divider)").removeClass($.mobile.activeBtnClass).attr("aria-selected",
false).each(function(i){if($.inArray(i,indicies)>-1){var item=$(this).addClass($.mobile.activeBtnClass);item.find("a").attr("aria-selected",true);if(isMultiple)item.find(".ui-icon").removeClass("ui-icon-checkbox-off").addClass("ui-icon-checkbox-on")}})},open:function(){if(this.options.disabled||this.options.nativeMenu)return;var self=this,menuHeight=self.list.parent().outerHeight(),menuWidth=self.list.parent().outerWidth(),scrollTop=$(window).scrollTop(),btnOffset=self.button.offset().top,screenHeight=
window.innerHeight,screenWidth=window.innerWidth;self.button.addClass($.mobile.activeBtnClass);setTimeout(function(){self.button.removeClass($.mobile.activeBtnClass)},300);function focusMenuItem(){self.list.find(".ui-btn-active").focus()}if(menuHeight>screenHeight-80||!$.support.scrollTop){if(scrollTop==0&&btnOffset>screenHeight)self.thisPage.one("pagehide",function(){$(this).jqmData("lastScroll",btnOffset)});self.menuPage.one("pageshow",function(){$(window).one("silentscroll",function(){focusMenuItem()})});
self.menuType="page";self.menuPageContent.append(self.list);$.mobile.changePage(self.menuPage,{transition:"pop"})}else{self.menuType="overlay";self.screen.height($(document).height()).removeClass("ui-screen-hidden");var roomtop=btnOffset-scrollTop,roombot=scrollTop+screenHeight-btnOffset,halfheight=menuHeight/2,maxwidth=parseFloat(self.list.parent().css("max-width")),newtop,newleft;if(roomtop>menuHeight/2&&roombot>menuHeight/2)newtop=btnOffset+self.button.outerHeight()/2-halfheight;else newtop=roomtop>
roombot?scrollTop+screenHeight-menuHeight-30:scrollTop+30;if(menuWidth<maxwidth)newleft=(screenWidth-menuWidth)/2;else{newleft=self.button.offset().left+self.button.outerWidth()/2-menuWidth/2;if(newleft<30)newleft=30;else if(newleft+menuWidth>screenWidth)newleft=screenWidth-menuWidth-30}self.listbox.append(self.list).removeClass("ui-selectmenu-hidden").css({top:newtop,left:newleft}).addClass("in");focusMenuItem()}setTimeout(function(){self.isOpen=true},400)},close:function(){if(this.options.disabled||
!this.isOpen||this.options.nativeMenu)return;var self=this;function focusButton(){setTimeout(function(){self.button.focus()},40);self.listbox.removeAttr("style").append(self.list)}if(self.menuType=="page"){self.menuPage.one("pagehide",focusButton);window.history.back()}else{self.screen.addClass("ui-screen-hidden");self.listbox.addClass("ui-selectmenu-hidden").removeAttr("style").removeClass("in");focusButton()}this.isOpen=false},disable:function(){this.element.attr("disabled",true);this.button.addClass("ui-disabled").attr("aria-disabled",
true);return this._setOption("disabled",true)},enable:function(){this.element.attr("disabled",false);this.button.removeClass("ui-disabled").attr("aria-disabled",false);return this._setOption("disabled",false)}})})(jQuery);
(function($,undefined){$.fn.buttonMarkup=function(options){return this.each(function(){var el=$(this),o=$.extend({},$.fn.buttonMarkup.defaults,el.jqmData(),options),buttonClass,innerClass="ui-btn-inner",iconClass;if(attachEvents)attachEvents();if(!o.theme){var themedParent=el.closest("[class*='ui-bar-'],[class*='ui-body-']");o.theme=themedParent.length?/ui-(bar|body)-([a-z])/.exec(themedParent.attr("class"))[2]:"c"}buttonClass="ui-btn ui-btn-up-"+o.theme;if(o.inline)buttonClass+=" ui-btn-inline";
if(o.icon){o.icon="ui-icon-"+o.icon;o.iconpos=o.iconpos||"left";iconClass="ui-icon "+o.icon;if(o.shadow)iconClass+=" ui-icon-shadow"}if(o.iconpos){buttonClass+=" ui-btn-icon-"+o.iconpos;if(o.iconpos=="notext"&&!el.attr("title"))el.attr("title",el.text())}if(o.corners){buttonClass+=" ui-btn-corner-all";innerClass+=" ui-btn-corner-all"}if(o.shadow)buttonClass+=" ui-shadow";el.attr("data-"+$.mobile.ns+"theme",o.theme).addClass(buttonClass);var wrap=("<D class='"+innerClass+"'><D class='ui-btn-text'></D>"+
(o.icon?"<span class='"+iconClass+"'></span>":"")+"</D>").replace(/D/g,o.wrapperEls);el.wrapInner(wrap)})};$.fn.buttonMarkup.defaults={corners:true,shadow:true,iconshadow:true,wrapperEls:"span"};function closestEnabledButton(element){while(element){var $ele=$(element);if($ele.hasClass("ui-btn")&&!$ele.hasClass("ui-disabled"))break;element=element.parentNode}return element}var attachEvents=function(){$(document).bind({"vmousedown":function(event){var btn=closestEnabledButton(event.target);if(btn){var $btn=
$(btn),theme=$btn.attr("data-"+$.mobile.ns+"theme");$btn.removeClass("ui-btn-up-"+theme).addClass("ui-btn-down-"+theme)}},"vmousecancel vmouseup":function(event){var btn=closestEnabledButton(event.target);if(btn){var $btn=$(btn),theme=$btn.attr("data-"+$.mobile.ns+"theme");$btn.removeClass("ui-btn-down-"+theme).addClass("ui-btn-up-"+theme)}},"vmouseover focus":function(event){var btn=closestEnabledButton(event.target);if(btn){var $btn=$(btn),theme=$btn.attr("data-"+$.mobile.ns+"theme");$btn.removeClass("ui-btn-up-"+
theme).addClass("ui-btn-hover-"+theme)}},"vmouseout blur":function(event){var btn=closestEnabledButton(event.target);if(btn){var $btn=$(btn),theme=$btn.attr("data-"+$.mobile.ns+"theme");$btn.removeClass("ui-btn-hover-"+theme).addClass("ui-btn-up-"+theme)}}});attachEvents=null}})(jQuery);
(function($,undefined){$.widget("mobile.button",$.mobile.widget,{options:{theme:null,icon:null,iconpos:null,inline:null,corners:true,shadow:true,iconshadow:true},_create:function(){var $el=this.element,o=this.options;this.button=$("<div></div>").text($el.text()||$el.val()).buttonMarkup({theme:o.theme,icon:o.icon,iconpos:o.iconpos,inline:o.inline,corners:o.corners,shadow:o.shadow,iconshadow:o.iconshadow}).insertBefore($el).append($el.addClass("ui-btn-hidden"));var type=$el.attr("type");if(type!=="button"&&
type!=="reset")$el.bind("vclick",function(){var $buttonPlaceholder=$("<input>",{type:"hidden",name:$el.attr("name"),value:$el.attr("value")}).insertBefore($el);$(document).submit(function(){$buttonPlaceholder.remove()})});this.refresh()},enable:function(){this.element.attr("disabled",false);this.button.removeClass("ui-disabled").attr("aria-disabled",false);return this._setOption("disabled",false)},disable:function(){this.element.attr("disabled",true);this.button.addClass("ui-disabled").attr("aria-disabled",
true);return this._setOption("disabled",true)},refresh:function(){if(this.element.attr("disabled"))this.disable();else this.enable()}})})(jQuery);
(function($,undefined){$.widget("mobile.slider",$.mobile.widget,{options:{theme:null,trackTheme:null,disabled:false},_create:function(){var self=this,control=this.element,parentTheme=control.parents("[class*=ui-bar-],[class*=ui-body-]").eq(0),parentTheme=parentTheme.length?parentTheme.attr("class").match(/ui-(bar|body)-([a-z])/)[2]:"c",theme=this.options.theme?this.options.theme:parentTheme,trackTheme=this.options.trackTheme?this.options.trackTheme:parentTheme,cType=control[0].nodeName.toLowerCase(),
selectClass=cType=="select"?"ui-slider-switch":"",controlID=control.attr("id"),labelID=controlID+"-label",label=$('[for="'+controlID+'"]').attr("id",labelID),val=function(){return cType=="input"?parseFloat(control.val()):control[0].selectedIndex},min=cType=="input"?parseFloat(control.attr("min")):0,max=cType=="input"?parseFloat(control.attr("max")):control.find("option").length-1,step=window.parseFloat(control.attr("step")||1),slider=$('<div class="ui-slider '+selectClass+" ui-btn-down-"+trackTheme+
' ui-btn-corner-all" role="application"></div>'),handle=$('<a href="#" class="ui-slider-handle"></a>').appendTo(slider).buttonMarkup({corners:true,theme:theme,shadow:true}).attr({"role":"slider","aria-valuemin":min,"aria-valuemax":max,"aria-valuenow":val(),"aria-valuetext":val(),"title":val(),"aria-labelledby":labelID});$.extend(this,{slider:slider,handle:handle,dragging:false,beforeStart:null});if(cType=="select"){slider.wrapInner('<div class="ui-slider-inneroffset"></div>');var options=control.find("option");
control.find("option").each(function(i){var side=i==0?"b":"a",corners=i==0?"right":"left",theme=i==0?" ui-btn-down-"+trackTheme:" ui-btn-active";$('<div class="ui-slider-labelbg ui-slider-labelbg-'+side+theme+" ui-btn-corner-"+corners+'"></div>').prependTo(slider);$('<span class="ui-slider-label ui-slider-label-'+side+theme+" ui-btn-corner-"+corners+'" role="img">'+$(this).text()+"</span>").prependTo(handle)})}label.addClass("ui-slider");control.addClass(cType=="input"?"ui-slider-input":"ui-slider-switch").change(function(){self.refresh(val(),
true)}).keyup(function(){self.refresh(val(),true,true)}).blur(function(){self.refresh(val(),true)});$(document).bind("vmousemove",function(event){if(self.dragging){self.refresh(event);return false}});slider.bind("vmousedown",function(event){self.dragging=true;if(cType==="select")self.beforeStart=control[0].selectedIndex;self.refresh(event);return false});slider.add(document).bind("vmouseup",function(){if(self.dragging){self.dragging=false;if(cType==="select"){if(self.beforeStart===control[0].selectedIndex)self.refresh(self.beforeStart===
0?1:0);var curval=val();var snapped=Math.round(curval/(max-min)*100);handle.addClass("ui-slider-handle-snapping").css("left",snapped+"%").animationComplete(function(){handle.removeClass("ui-slider-handle-snapping")})}return false}});slider.insertAfter(control);this.handle.bind("vmousedown",function(){$(this).focus()}).bind("vclick",false);this.handle.bind("keydown",function(event){var index=val();if(self.options.disabled)return;switch(event.keyCode){case $.mobile.keyCode.HOME:case $.mobile.keyCode.END:case $.mobile.keyCode.PAGE_UP:case $.mobile.keyCode.PAGE_DOWN:case $.mobile.keyCode.UP:case $.mobile.keyCode.RIGHT:case $.mobile.keyCode.DOWN:case $.mobile.keyCode.LEFT:event.preventDefault();
if(!self._keySliding){self._keySliding=true;$(this).addClass("ui-state-active")}break}switch(event.keyCode){case $.mobile.keyCode.HOME:self.refresh(min);break;case $.mobile.keyCode.END:self.refresh(max);break;case $.mobile.keyCode.PAGE_UP:case $.mobile.keyCode.UP:case $.mobile.keyCode.RIGHT:self.refresh(index+step);break;case $.mobile.keyCode.PAGE_DOWN:case $.mobile.keyCode.DOWN:case $.mobile.keyCode.LEFT:self.refresh(index-step);break}}).keyup(function(event){if(self._keySliding){self._keySliding=
false;$(this).removeClass("ui-state-active")}});this.refresh()},refresh:function(val,isfromControl,preventInputUpdate){if(this.options.disabled)return;var control=this.element,percent,cType=control[0].nodeName.toLowerCase(),min=cType==="input"?parseFloat(control.attr("min")):0,max=cType==="input"?parseFloat(control.attr("max")):control.find("option").length-1;if(typeof val==="object"){var data=val,tol=8;if(!this.dragging||data.pageX<this.slider.offset().left-tol||data.pageX>this.slider.offset().left+
this.slider.width()+tol)return;percent=Math.round((data.pageX-this.slider.offset().left)/this.slider.width()*100)}else{if(val==null)val=cType==="input"?parseFloat(control.val()):control[0].selectedIndex;percent=(parseFloat(val)-min)/(max-min)*100}if(isNaN(percent))return;if(percent<0)percent=0;if(percent>100)percent=100;var newval=Math.round(percent/100*(max-min))+min;if(newval<min)newval=min;if(newval>max)newval=max;if(percent>60&&cType==="select");this.handle.css("left",percent+"%");this.handle.attr({"aria-valuenow":cType===
"input"?newval:control.find("option").eq(newval).attr("value"),"aria-valuetext":cType==="input"?newval:control.find("option").eq(newval).text(),title:newval});if(cType==="select")if(newval===0)this.slider.addClass("ui-slider-switch-a").removeClass("ui-slider-switch-b");else this.slider.addClass("ui-slider-switch-b").removeClass("ui-slider-switch-a");if(!preventInputUpdate){if(cType==="input")control.val(newval);else control[0].selectedIndex=newval;if(!isfromControl)control.trigger("change")}},enable:function(){this.element.attr("disabled",
false);this.slider.removeClass("ui-disabled").attr("aria-disabled",false);return this._setOption("disabled",false)},disable:function(){this.element.attr("disabled",true);this.slider.addClass("ui-disabled").attr("aria-disabled",true);return this._setOption("disabled",true)}})})(jQuery);
(function($,undefined){$.widget("mobile.collapsible",$.mobile.widget,{options:{expandCueText:" click to expand contents",collapseCueText:" click to collapse contents",collapsed:false,heading:">:header,>legend",theme:null,iconTheme:"d"},_create:function(){var $el=this.element,o=this.options,collapsibleContain=$el.addClass("ui-collapsible-contain"),collapsibleHeading=$el.find(o.heading).eq(0),collapsibleContent=collapsibleContain.wrapInner('<div class="ui-collapsible-content"></div>').find(".ui-collapsible-content"),
collapsibleParent=$el.closest(":jqmData(role='collapsible-set')").addClass("ui-collapsible-set");if(collapsibleHeading.is("legend")){collapsibleHeading=$('<div role="heading">'+collapsibleHeading.html()+"</div>").insertBefore(collapsibleHeading);collapsibleHeading.next().remove()}collapsibleHeading.insertBefore(collapsibleContent).addClass("ui-collapsible-heading").append('<span class="ui-collapsible-heading-status"></span>').wrapInner('<a href="#" class="ui-collapsible-heading-toggle"></a>').find("a:eq(0)").buttonMarkup({shadow:!collapsibleParent.length,
corners:false,iconPos:"left",icon:"plus",theme:o.theme}).find(".ui-icon").removeAttr("class").buttonMarkup({shadow:true,corners:true,iconPos:"notext",icon:"plus",theme:o.iconTheme});if(!collapsibleParent.length)collapsibleHeading.find("a:eq(0)").addClass("ui-corner-all").find(".ui-btn-inner").addClass("ui-corner-all");else if(collapsibleContain.jqmData("collapsible-last"))collapsibleHeading.find("a:eq(0), .ui-btn-inner").addClass("ui-corner-bottom");collapsibleContain.bind("collapse",function(event){if(!event.isDefaultPrevented()&&
$(event.target).closest(".ui-collapsible-contain").is(collapsibleContain)){event.preventDefault();collapsibleHeading.addClass("ui-collapsible-heading-collapsed").find(".ui-collapsible-heading-status").text(o.expandCueText).end().find(".ui-icon").removeClass("ui-icon-minus").addClass("ui-icon-plus");collapsibleContent.addClass("ui-collapsible-content-collapsed").attr("aria-hidden",true);if(collapsibleContain.jqmData("collapsible-last"))collapsibleHeading.find("a:eq(0), .ui-btn-inner").addClass("ui-corner-bottom")}}).bind("expand",
function(event){if(!event.isDefaultPrevented()){event.preventDefault();collapsibleHeading.removeClass("ui-collapsible-heading-collapsed").find(".ui-collapsible-heading-status").text(o.collapseCueText);collapsibleHeading.find(".ui-icon").removeClass("ui-icon-plus").addClass("ui-icon-minus");collapsibleContent.removeClass("ui-collapsible-content-collapsed").attr("aria-hidden",false);if(collapsibleContain.jqmData("collapsible-last"))collapsibleHeading.find("a:eq(0), .ui-btn-inner").removeClass("ui-corner-bottom")}}).trigger(o.collapsed?
"collapse":"expand");if(collapsibleParent.length&&!collapsibleParent.jqmData("collapsiblebound")){collapsibleParent.jqmData("collapsiblebound",true).bind("expand",function(event){$(event.target).closest(".ui-collapsible-contain").siblings(".ui-collapsible-contain").trigger("collapse")});var set=collapsibleParent.find(":jqmData(role='collapsible'):first");set.first().find("a:eq(0)").addClass("ui-corner-top").find(".ui-btn-inner").addClass("ui-corner-top");set.last().jqmData("collapsible-last",true)}collapsibleHeading.bind("vclick",
function(e){if(collapsibleHeading.is(".ui-collapsible-heading-collapsed"))collapsibleContain.trigger("expand");else collapsibleContain.trigger("collapse");e.preventDefault()})}})})(jQuery);
(function($,undefined){$.fn.controlgroup=function(options){return this.each(function(){var o=$.extend({direction:$(this).jqmData("type")||"vertical",shadow:false},options);var groupheading=$(this).find(">legend"),flCorners=o.direction=="horizontal"?["ui-corner-left","ui-corner-right"]:["ui-corner-top","ui-corner-bottom"],type=$(this).find("input:eq(0)").attr("type");if(groupheading.length){$(this).wrapInner('<div class="ui-controlgroup-controls"></div>');$('<div role="heading" class="ui-controlgroup-label">'+
groupheading.html()+"</div>").insertBefore($(this).children(0));groupheading.remove()}$(this).addClass("ui-corner-all ui-controlgroup ui-controlgroup-"+o.direction);function flipClasses(els){els.removeClass("ui-btn-corner-all ui-shadow").eq(0).addClass(flCorners[0]).end().filter(":last").addClass(flCorners[1]).addClass("ui-controlgroup-last")}flipClasses($(this).find(".ui-btn"));flipClasses($(this).find(".ui-btn-inner"));if(o.shadow)$(this).addClass("ui-shadow")})}})(jQuery);
(function($,undefined){$.fn.fieldcontain=function(options){return this.addClass("ui-field-contain ui-body ui-br")}})(jQuery);
(function($,undefined){var listCountPerPage={};$.widget("mobile.listview",$.mobile.widget,{options:{theme:"c",countTheme:"c",headerTheme:"b",dividerTheme:"b",splitIcon:"arrow-r",splitTheme:"b",inset:false},_create:function(){var t=this;t.element.addClass(function(i,orig){return orig+" ui-listview "+(t.options.inset?" ui-listview-inset ui-corner-all ui-shadow ":"")});t.refresh()},_itemApply:function($list,item){item.find(".ui-li-count").addClass("ui-btn-up-"+($list.jqmData("counttheme")||this.options.countTheme)+
" ui-btn-corner-all").end().find("h1, h2, h3, h4, h5, h6").addClass("ui-li-heading").end().find("p, dl").addClass("ui-li-desc").end().find(">img:eq(0), .ui-link-inherit>img:eq(0)").addClass("ui-li-thumb").each(function(){item.addClass($(this).is(".ui-li-icon")?"ui-li-has-icon":"ui-li-has-thumb")}).end().find(".ui-li-aside").each(function(){var $this=$(this);$this.prependTo($this.parent())})},_removeCorners:function(li){li.add(li.find(".ui-btn-inner, .ui-li-link-alt, .ui-li-thumb")).removeClass("ui-corner-top ui-corner-bottom ui-corner-br ui-corner-bl ui-corner-tr ui-corner-tl")},
refresh:function(create){this._createSubPages();var o=this.options,$list=this.element,self=this,dividertheme=$list.jqmData("dividertheme")||o.dividerTheme,listsplittheme=$list.jqmData("splittheme"),listspliticon=$list.jqmData("spliticon"),li=$list.children("li"),counter=$.support.cssPseudoElement||!$.nodeName($list[0],"ol")?0:1;if(counter)$list.find(".ui-li-dec").remove();for(var pos=0,numli=li.length;pos<numli;pos++){var item=li.eq(pos),itemClass="ui-li";if(create||!item.hasClass("ui-li")){var itemTheme=
item.jqmData("theme")||o.theme,a=item.children("a");if(a.length){var icon=item.jqmData("icon");item.buttonMarkup({wrapperEls:"div",shadow:false,corners:false,iconpos:"right",icon:a.length>1||icon===false?false:icon||"arrow-r",theme:itemTheme});a.first().addClass("ui-link-inherit");if(a.length>1){itemClass+=" ui-li-has-alt";var last=a.last(),splittheme=listsplittheme||last.jqmData("theme")||o.splitTheme;last.appendTo(item).attr("title",last.text()).addClass("ui-li-link-alt").empty().buttonMarkup({shadow:false,
corners:false,theme:itemTheme,icon:false,iconpos:false}).find(".ui-btn-inner").append($("<span />").buttonMarkup({shadow:true,corners:true,theme:splittheme,iconpos:"notext",icon:listspliticon||last.jqmData("icon")||o.splitIcon}))}}else if(item.jqmData("role")==="list-divider"){itemClass+=" ui-li-divider ui-btn ui-bar-"+dividertheme;item.attr("role","heading");if(counter)counter=1}else itemClass+=" ui-li-static ui-body-"+itemTheme}if(o.inset){if(pos===0){itemClass+=" ui-corner-top";item.add(item.find(".ui-btn-inner")).find(".ui-li-link-alt").addClass("ui-corner-tr").end().find(".ui-li-thumb").addClass("ui-corner-tl");
if(item.next().next().length)self._removeCorners(item.next())}if(pos===li.length-1){itemClass+=" ui-corner-bottom";item.add(item.find(".ui-btn-inner")).find(".ui-li-link-alt").addClass("ui-corner-br").end().find(".ui-li-thumb").addClass("ui-corner-bl");if(item.prev().prev().length)self._removeCorners(item.prev())}}if(counter&&itemClass.indexOf("ui-li-divider")<0){var countParent=item.is(".ui-li-static:first")?item:item.find(".ui-link-inherit");countParent.addClass("ui-li-jsnumbering").prepend("<span class='ui-li-dec'>"+
counter++ +". </span>")}item.add(item.children(".ui-btn-inner")).addClass(itemClass);if(!create)self._itemApply($list,item)}},_idStringEscape:function(str){return str.replace(/[^a-zA-Z0-9]/g,"-")},_createSubPages:function(){var parentList=this.element,parentPage=parentList.closest(".ui-page"),parentUrl=parentPage.jqmData("url"),parentId=parentUrl||parentPage[0][$.expando],parentListId=parentList.attr("id"),o=this.options,dns="data-"+$.mobile.ns,self=this,persistentFooterID=parentPage.find(":jqmData(role='footer')").jqmData("id");
if(typeof listCountPerPage[parentId]==="undefined")listCountPerPage[parentId]=-1;parentListId=parentListId||++listCountPerPage[parentId];$(parentList.find("li>ul, li>ol").toArray().reverse()).each(function(i){var list=$(this),listId=list.attr("id")||parentListId+"-"+i,parent=list.parent(),nodeEls=$(list.prevAll().toArray().reverse()),nodeEls=nodeEls.length?nodeEls:$("<span>"+$.trim(parent.contents()[0].nodeValue)+"</span>"),title=nodeEls.first().text(),id=(parentUrl||"")+"&"+$.mobile.subPageUrlKey+
"="+listId;theme=list.jqmData("theme")||o.theme,countTheme=list.jqmData("counttheme")||parentList.jqmData("counttheme")||o.countTheme,newPage=list.detach().wrap("<div "+dns+"role='page' "+dns+"url='"+id+"' "+dns+"theme='"+theme+"' "+dns+"count-theme='"+countTheme+"'><div "+dns+"role='content'></div></div>").parent().before("<div "+dns+"role='header' "+dns+"theme='"+o.headerTheme+"'><div class='ui-title'>"+title+"</div></div>").after(persistentFooterID?$("<div "+dns+"role='footer' "+dns+"id='"+persistentFooterID+
"'>"):"").parent().appendTo($.mobile.pageContainer);newPage.page();var anchor=parent.find("a:first");if(!anchor.length)anchor=$("<a />").html(nodeEls||title).prependTo(parent.empty());anchor.attr("href","#"+id)}).listview()}})})(jQuery);
(function($,undefined){$.mobile.listview.prototype.options.filter=false;$.mobile.listview.prototype.options.filterPlaceholder="Filter items...";$.mobile.listview.prototype.options.filterTheme="c";$(":jqmData(role='listview')").live("listviewcreate",function(){var list=$(this),listview=list.data("listview");if(!listview.options.filter)return;var wrapper=$("<form>",{"class":"ui-listview-filter ui-bar-"+listview.options.filterTheme,"role":"search"}),search=$("<input>",{placeholder:listview.options.filterPlaceholder}).attr("data-"+
$.mobile.ns+"type","search").jqmData("lastval","").bind("keyup change",function(){var val=this.value.toLowerCase(),listItems=null,lastval=$(this).jqmData("lastval")+"";$(this).jqmData("lastval",val);change=val.replace(new RegExp("^"+lastval),"");if(val.length<lastval.length||change.length!=val.length-lastval.length)listItems=list.children();else listItems=list.children(":not(.ui-screen-hidden)");if(val){var item,childItems=false,itemtext="";for(var i=listItems.length-1;i>=0;i--){item=$(listItems[i]);
itemtext=item.jqmData("filtertext")||item.text();if(item.is("li:jqmData(role=list-divider)")){item.toggleClass("ui-filter-hidequeue",!childItems);childItems=false}else if(itemtext.toLowerCase().indexOf(val)===-1)item.toggleClass("ui-filter-hidequeue",true);else childItems=true}listItems.filter(":not(.ui-filter-hidequeue)").toggleClass("ui-screen-hidden",false);listItems.filter(".ui-filter-hidequeue").toggleClass("ui-screen-hidden",true).toggleClass("ui-filter-hidequeue",false)}else listItems.toggleClass("ui-screen-hidden",
false)}).appendTo(wrapper).textinput();if($(this).jqmData("inset"))wrapper.addClass("ui-listview-filter-inset");wrapper.insertBefore(list)})})(jQuery);
(function($,undefined){$.widget("mobile.dialog",$.mobile.widget,{options:{closeBtnText:"Close"},_create:function(){var $el=this.element;$el.attr("role","dialog").addClass("ui-page ui-dialog ui-body-a").find(":jqmData(role=header)").addClass("ui-corner-top ui-overlay-shadow").prepend("<a href='#' data-"+$.mobile.ns+"icon='delete' data-"+$.mobile.ns+"rel='back' data-"+$.mobile.ns+"iconpos='notext'>"+this.options.closeBtnText+"</a>").end().find('.ui-content:not([class*="ui-body-"])').addClass("ui-body-c").end().find(".ui-content,:jqmData(role='footer')").last().addClass("ui-corner-bottom ui-overlay-shadow");
$el.bind("vclick submit",function(e){var $target=$(e.target).closest(e.type==="vclick"?"a":"form");if($target.length&&!$target.jqmData("transition")){var active=$.mobile.urlHistory.getActive()||{};$target.attr("data-"+$.mobile.ns+"transition",active.transition||$.mobile.defaultDialogTransition).attr("data-"+$.mobile.ns+"direction","reverse")}}).bind("pagehide",function(){$(this).find("."+$.mobile.activeBtnClass).removeClass($.mobile.activeBtnClass)})},close:function(){window.history.back()}})})(jQuery);
(function($,undefined){$.widget("mobile.navbar",$.mobile.widget,{options:{iconpos:"top",grid:null},_create:function(){var $navbar=this.element,$navbtns=$navbar.find("a"),iconpos=$navbtns.filter(":jqmData(icon)").length?this.options.iconpos:undefined;$navbar.addClass("ui-navbar").attr("role","navigation").find("ul").grid({grid:this.options.grid});if(!iconpos)$navbar.addClass("ui-navbar-noicons");$navbtns.buttonMarkup({corners:false,shadow:false,iconpos:iconpos});$navbar.delegate("a","vclick",function(event){$navbtns.not(".ui-state-persist").removeClass($.mobile.activeBtnClass);
$(this).addClass($.mobile.activeBtnClass)})}})})(jQuery);
(function($,undefined){$.fn.grid=function(options){return this.each(function(){var o=$.extend({grid:null},options);var $kids=$(this).children(),gridCols={solo:1,a:2,b:3,c:4,d:5},grid=o.grid,iterator;if(!grid)if($kids.length<=5)for(var letter in gridCols){if(gridCols[letter]==$kids.length)grid=letter}else grid="a";iterator=gridCols[grid];$(this).addClass("ui-grid-"+grid);$kids.filter(":nth-child("+iterator+"n+1)").addClass("ui-block-a");if(iterator>1)$kids.filter(":nth-child("+iterator+"n+2)").addClass("ui-block-b");
if(iterator>2)$kids.filter(":nth-child(3n+3)").addClass("ui-block-c");if(iterator>3)$kids.filter(":nth-child(4n+4)").addClass("ui-block-d");if(iterator>4)$kids.filter(":nth-child(5n+5)").addClass("ui-block-e")})}})(jQuery);
(function($,window,undefined){var $html=$("html"),$head=$("head"),$window=$(window);$(window.document).trigger("mobileinit");if(!$.mobile.gradeA())return;if(window.blackberry&&!window.WebKitPoint||window.operamini&&Object.prototype.toString.call(window.operamini)==="[object OperaMini]")$.mobile.ajaxEnabled=false;$html.addClass("ui-mobile ui-mobile-rendering");var $loader=$.mobile.loadingMessage?$("<div class='ui-loader ui-body-a ui-corner-all'>"+"<span class='ui-icon ui-icon-loading spin'></span>"+
"<h1>"+$.mobile.loadingMessage+"</h1>"+"</div>"):undefined;$.extend($.mobile,{showPageLoadingMsg:function(){if($.mobile.loadingMessage){var activeBtn=$("."+$.mobile.activeBtnClass).first();$loader.appendTo($.mobile.pageContainer).css({top:$.support.scrollTop&&$(window).scrollTop()+$(window).height()/2||activeBtn.length&&activeBtn.offset().top||100})}$html.addClass("ui-loading")},hidePageLoadingMsg:function(){$html.removeClass("ui-loading")},pageLoading:function(done){if(done)$.mobile.hidePageLoadingMsg();
else $.mobile.showPageLoadingMsg()},initializePage:function(){var $pages=$(":jqmData(role='page')");$pages.add(":jqmData(role='dialog')").each(function(){var $this=$(this);if(!$this.jqmData("url"))$this.attr("data-"+$.mobile.ns+"url",$this.attr("id"))});$.mobile.firstPage=$pages.first();$.mobile.pageContainer=$pages.first().parent().addClass("ui-mobile-viewport");$.mobile.showPageLoadingMsg();if(!$.mobile.hashListeningEnabled||!$.mobile.path.stripHash(location.hash))$.mobile.changePage($.mobile.firstPage,
{transition:"none",reverse:true,changeHash:false,fromHashChange:true});else $window.trigger("hashchange",[true])}});$(function(){window.scrollTo(0,1);$.mobile.defaultHomeScroll=!$.support.scrollTop||$(window).scrollTop()===1?0:1;$($.mobile.initializePage);$window.load($.mobile.silentScroll)})})(jQuery,this);(function($,undefined){$.widget("mobile.tabs",$.mobile.widget,{options:{iconpos:"top",grid:null,load:function(event,ui){},beforeTabHide:function(event,ui){return true},beforeTabShow:function(event,ui){return true},afterTabShow:function(event,ui){return true},selector:'div[data-role="content"]'},_create:function(){var $this=this,$tabs=this.element,$navbtns=$tabs.find("a"),iconpos=$navbtns.filter("[data-icon]").length?this.options.iconpos:undefined;var $content=$tabs.closest('div[data-role="page"]').find(this.options.selector);
$tabs.addClass("ui-navbar").attr("role","navigation").find("ul").grid({grid:this.options.grid});if(!iconpos)$tabs.addClass("ui-navbar-noicons");$navbtns.buttonMarkup({corners:false,shadow:false,iconpos:iconpos}).removeClass("ui-link");$tabs.delegate("a","click",function(event){$navbtns.removeClass("ui-btn-active");$(this).addClass("ui-btn-active");event.preventDefault();return false});$content.children().addClass("ui-tabs-content");if($navbtns.filter(".ui-btn-active").length==0)$navbtns.first().addClass("ui-btn-active");
$content.children("#"+$navbtns.eq($this.currentTab()).attr("href")).addClass("ui-tabs-content-active");$navbtns.bind("click",function(event){$this.changeTab(event,{currentTab:$navbtns.eq($this.currentTab()),nextTab:$(this),currentContent:$this.currentContent(),nextContent:$content.children($(this).attr("href"))})});this._trigger("load",null,{currentTab:$navbtns.eq($this.currentTab()),currentContent:$this.currentContent()})},currentTab:function(){var $tabs=this.element,$navbtns=$tabs.find("a");return this.element.find(".ui-btn-active").parent().prevAll().length},
currentContent:function(){return this.element.closest('div[data-role="page"]').find(this.options.selector).children().filter(".ui-tabs-content-active")},changeTab:function(event,ui){if(this._trigger("beforeTabHide",event,ui))ui.currentContent.siblings().andSelf().removeClass("ui-tabs-content-active");if(this._trigger("beforeTabShow",event,ui))ui.nextContent.addClass("ui-tabs-content-active");this._trigger("afterTabShow",event,$.extend({},ui,{previousContent:ui.currentContent,currentContent:ui.nextContent,
nextContent:null}))}})})(jQuery);$(function(){$("[data-role=page]").live("pagecreate",function(e){$(this).find('[data-role="tabs"]').tabs()})});/*
 
 jQuery Tools @VERSION / Flashembed - New wave Flash embedding

 NO COPYRIGHTS OR LICENSES. DO WHAT YOU LIKE.

 http://flowplayer.org/tools/toolbox/flashembed.html

 Since : March 2008
 Date  : @DATE 
*/
(function(){var IE=document.all,URL="http://www.adobe.com/go/getflashplayer",JQUERY=typeof jQuery=="function",RE=/(\d+)[^\d]+(\d+)[^\d]*(\d*)/,GLOBAL_OPTS={width:"100%",height:"100%",id:"_"+(""+Math.random()).slice(9),allowfullscreen:true,allowscriptaccess:"always",quality:"high",version:[3,0],onFail:null,expressInstall:null,w3c:false,cachebusting:false};if(window.attachEvent)window.attachEvent("onbeforeunload",function(){__flash_unloadHandler=function(){};__flash_savedUnloadHandler=function(){}});
function extend(to,from){if(from)for(var key in from)if(from.hasOwnProperty(key))to[key]=from[key];return to}function map(arr,func){var newArr=[];for(var i in arr)if(arr.hasOwnProperty(i))newArr[i]=func(arr[i]);return newArr}window.flashembed=function(root,opts,conf){if(typeof root=="string")root=document.getElementById(root.replace("#",""));if(!root)return;if(typeof opts=="string")opts={src:opts};return new Flash(root,extend(extend({},GLOBAL_OPTS),opts),conf)};var f=extend(window.flashembed,{conf:GLOBAL_OPTS,
getVersion:function(){var fo,ver;try{ver=navigator.plugins["Shockwave Flash"].description.slice(16)}catch(e){try{fo=new ActiveXObject("ShockwaveFlash.ShockwaveFlash.7");ver=fo&&fo.GetVariable("$version")}catch(err){try{fo=new ActiveXObject("ShockwaveFlash.ShockwaveFlash.6");ver=fo&&fo.GetVariable("$version")}catch(err2){}}}ver=RE.exec(ver);return ver?[ver[1],ver[3]]:[0,0]},asString:function(obj){if(obj===null||obj===undefined)return null;var type=typeof obj;if(type=="object"&&obj.push)type="array";
switch(type){case "string":obj=obj.replace(new RegExp('(["\\\\])',"g"),"\\$1");obj=obj.replace(/^\s?(\d+\.?\d+)%/,"$1pct");return'"'+obj+'"';case "array":return"["+map(obj,function(el){return f.asString(el)}).join(",")+"]";case "function":return'"function()"';case "object":var str=[];for(var prop in obj)if(obj.hasOwnProperty(prop))str.push('"'+prop+'":'+f.asString(obj[prop]));return"{"+str.join(",")+"}"}return String(obj).replace(/\s/g," ").replace(/\'/g,'"')},getHTML:function(opts,conf){opts=extend({},
opts);var html='<object width="'+opts.width+'" height="'+opts.height+'" id="'+opts.id+'" name="'+opts.id+'"';if(opts.cachebusting)opts.src+=(opts.src.indexOf("?")!=-1?"&":"?")+Math.random();if(opts.w3c||!IE)html+=' data="'+opts.src+'" type="application/x-shockwave-flash"';else html+=' classid="clsid:D27CDB6E-AE6D-11cf-96B8-444553540000"';html+=">";if(opts.w3c||IE)html+='<param name="movie" value="'+opts.src+'" />';opts.width=opts.height=opts.id=opts.w3c=opts.src=null;opts.onFail=opts.version=opts.expressInstall=
null;for(var key in opts)if(opts[key])html+='<param name="'+key+'" value="'+opts[key]+'" />';var vars="";if(conf){for(var k in conf)if(conf[k]){var val=conf[k];vars+=k+"="+(/function|object/.test(typeof val)?f.asString(val):val)+"&"}vars=vars.slice(0,-1);html+='<param name="flashvars" value=\''+vars+"' />"}html+="</object>";return html},isSupported:function(ver){return VERSION[0]>ver[0]||VERSION[0]==ver[0]&&VERSION[1]>=ver[1]}});var VERSION=f.getVersion();function Flash(root,opts,conf){if(f.isSupported(opts.version))root.innerHTML=
f.getHTML(opts,conf);else if(opts.expressInstall&&f.isSupported([6,65]))root.innerHTML=f.getHTML(extend(opts,{src:opts.expressInstall}),{MMredirectURL:location.href,MMplayerType:"PlugIn",MMdoctitle:document.title});else{if(!root.innerHTML.replace(/\s/g,"")){root.innerHTML="<h2>Flash version "+opts.version+" or greater is required</h2>"+"<h3>"+(VERSION[0]>0?"Your version is "+VERSION:"You have no flash plugin installed")+"</h3>"+(root.tagName=="A"?"<p>Click here to download latest version</p>":"<p>Download latest version from <a href='"+
URL+"'>here</a></p>");if(root.tagName=="A")root.onclick=function(){location.href=URL}}if(opts.onFail){var ret=opts.onFail.call(this);if(typeof ret=="string")root.innerHTML=ret}}if(IE)window[opts.id]=document.getElementById(opts.id);extend(this,{getRoot:function(){return root},getOptions:function(){return opts},getConf:function(){return conf},getApi:function(){return root.firstChild}})}if(JQUERY){jQuery.tools=jQuery.tools||{version:"@VERSION"};jQuery.tools.flashembed={conf:GLOBAL_OPTS};jQuery.fn.flashembed=
function(opts,conf){return this.each(function(){$(this).data("flashembed",flashembed(this,opts,conf))})}}})();(function(g){for(var d,j=document.getElementsByTagName("head")[0].style,h="transformProperty WebkitTransform OTransform msTransform MozTransform".split(" "),e=0;e<h.length;e++)j[h[e]]!==void 0&&(d=h[e]);var i="v"=="\u000b";jQuery.fn.extend({ImageRotate:function(a){if(!this.Wilq32||!this.Wilq32.PhotoEffect)return a=g.extend(!0,{},a),(new Wilq32.PhotoEffect(this.get(0),a))._rootObj},rotate:function(a){if(!(this.length===0||typeof a=="undefined")){typeof a=="number"&&(a={angle:a});for(var c=[],b=0,d=
this.length;b<d;b++){var f=this.get(b);typeof f.Wilq32=="undefined"?c.push(g(g(f).ImageRotate(a))):f.Wilq32.PhotoEffect._handleRotation(a)}return c}}});Wilq32=window.Wilq32||{};Wilq32.PhotoEffect=function(){return d?function(a,c){a.Wilq32={PhotoEffect:this};this._img=this._rootObj=this._eventObj=a;this._handleRotation(c)}:function(a,c){this._img=a;this._rootObj=document.createElement("span");this._rootObj.style.display="inline-block";this._rootObj.Wilq32={PhotoEffect:this};a.parentNode.insertBefore(this._rootObj,
a);if(a.complete)this._Loader(c);else{var b=this;jQuery(this._img).bind("load",function(){b._Loader(c)})}}}();Wilq32.PhotoEffect.prototype={_setupParameters:function(a){this._parameters=this._parameters||{};if(typeof this._angle!=="number")this._angle=0;if(typeof a.angle==="number")this._angle=a.angle;this._parameters.animateTo=typeof a.animateTo==="number"?a.animateTo:this._angle;this._parameters.easing=a.easing||this._parameters.easing||function(a,b,d,f,e){return-f*((b=b/e-1)*b*b*b-1)+d};this._parameters.duration=
a.duration||this._parameters.duration||1E3;this._parameters.callback=a.callback||this._parameters.callback||function(){};a.bind&&a.bind!=this._parameters.bind&&this._BindEvents(a.bind)},_handleRotation:function(a){this._setupParameters(a);this._angle==this._parameters.animateTo?this._rotate(this._angle):this._animateStart()},_BindEvents:function(a){if(a&&this._eventObj){if(this._parameters.bind){var c=this._parameters.bind,b;for(b in c)c.hasOwnProperty(b)&&jQuery(this._eventObj).unbind(b,c[b])}this._parameters.bind=
a;for(b in a)a.hasOwnProperty(b)&&jQuery(this._eventObj).bind(b,a[b])}},_Loader:function(){return i?function(a){var c=this._img.width,b=this._img.height;this._img.parentNode.removeChild(this._img);this._vimage=this.createVMLNode("image");this._vimage.src=this._img.src;this._vimage.style.height=b+"px";this._vimage.style.width=c+"px";this._vimage.style.position="absolute";this._vimage.style.top="0px";this._vimage.style.left="0px";this._container=this.createVMLNode("group");this._container.style.width=
c;this._container.style.height=b;this._container.style.position="absolute";this._container.setAttribute("coordsize",c-1+","+(b-1));this._container.appendChild(this._vimage);this._rootObj.appendChild(this._container);this._rootObj.style.position="relative";this._rootObj.style.width=c+"px";this._rootObj.style.height=b+"px";this._rootObj.setAttribute("id",this._img.getAttribute("id"));this._rootObj.className=this._img.className;this._eventObj=this._rootObj;this._handleRotation(a)}:function(a){this._rootObj.setAttribute("id",
this._img.getAttribute("id"));this._rootObj.className=this._img.className;this._width=this._img.width;this._height=this._img.height;this._widthHalf=this._width/2;this._heightHalf=this._height/2;var c=Math.sqrt(this._height*this._height+this._width*this._width);this._widthAdd=c-this._width;this._heightAdd=c-this._height;this._widthAddHalf=this._widthAdd/2;this._heightAddHalf=this._heightAdd/2;this._img.parentNode.removeChild(this._img);this._aspectW=(parseInt(this._img.style.width,10)||this._width)/
this._img.width;this._aspectH=(parseInt(this._img.style.height,10)||this._height)/this._img.height;this._canvas=document.createElement("canvas");this._canvas.setAttribute("width",this._width);this._canvas.style.position="relative";this._canvas.style.left=-this._widthAddHalf+"px";this._canvas.style.top=-this._heightAddHalf+"px";this._canvas.Wilq32=this._rootObj.Wilq32;this._rootObj.appendChild(this._canvas);this._rootObj.style.width=this._width+"px";this._rootObj.style.height=this._height+"px";this._eventObj=
this._canvas;this._cnv=this._canvas.getContext("2d");this._handleRotation(a)}}(),_animateStart:function(){this._timer&&clearTimeout(this._timer);this._animateStartTime=+new Date;this._animateStartAngle=this._angle;this._animate()},_animate:function(){var a=+new Date,c=a-this._animateStartTime>this._parameters.duration;if(c&&!this._parameters.animatedGif)clearTimeout(this._timer);else{(this._canvas||this._vimage||this._img)&&this._rotate(~~(this._parameters.easing(0,a-this._animateStartTime,this._animateStartAngle,
this._parameters.animateTo-this._animateStartAngle,this._parameters.duration)*10)/10);var b=this;this._timer=setTimeout(function(){b._animate.call(b)},10)}if(this._parameters.callback&&c)this._angle=this._parameters.animateTo,this._rotate(this._angle),this._parameters.callback.call(this._rootObj)},_rotate:function(){var a=Math.PI/180;return i?function(a){this._angle=a;this._container.style.rotation=a%360+"deg"}:d?function(a){this._angle=a;this._img.style[d]="rotate("+a%360+"deg)"}:function(c){this._angle=
c;c=c%360*a;this._canvas.width=this._width+this._widthAdd;this._canvas.height=this._height+this._heightAdd;this._cnv.translate(this._widthAddHalf,this._heightAddHalf);this._cnv.translate(this._widthHalf,this._heightHalf);this._cnv.rotate(c);this._cnv.translate(-this._widthHalf,-this._heightHalf);this._cnv.scale(this._aspectW,this._aspectH);this._cnv.drawImage(this._img,0,0)}}()};if(i)Wilq32.PhotoEffect.prototype.createVMLNode=function(){document.createStyleSheet().addRule(".rvml","behavior:url(#default#VML)");
try{return!document.namespaces.rvml&&document.namespaces.add("rvml","urn:schemas-microsoft-com:vml"),function(a){return document.createElement("<rvml:"+a+' class="rvml">')}}catch(a){return function(a){return document.createElement("<"+a+' xmlns="urn:schemas-microsoft.com:vml" class="rvml">')}}}()})(jQuery);