.video-holder {
    float: none;
}

.min-width-480px .video-holder {
    float: left;
}

.max-width-480px .inline.ui-grid-a .ui-block-a, 
    .max-width-480px .inline.ui-grid-a .ui-block-b {
    width: 100%;
    clear: left;
}

.video-player {
    padding: 0px;
    margin: 0px;
}

.ui-video-player {
    padding: 0px !important;
    margin: 0px !important;
    margin-left: 15px !important;
}

.video-player {
    padding-top: 0px;
    margin: 0px;
}

.ui-content-marginless {
    margin: 0px !important;
    padding-top: 0px !important;
    padding-bottom: 0px !important;
    overflow-y: hidden !important;
}

.ui-content {
    //
    //margin: 0px !important;
}

.top-front {
    z-index: 1000;
}

.video-controls {
    padding: 0px;
    margin: 0px;
    min-width: 200px;
    border-width: 0px;
}

.video-controls form {
    margin: 0px 10px;
}

.min-width-768px .video-controls {
    clear: none;
    /*  width: 200px; */
}

.information-label {
    width: 30%;
    clear: left;
    float: left;
    display: block;
}

.information-value {
    font-weight: bold;
    display: block;
}

.max-width-768px .optional {
    display: none !important; 
}

#home .ui-content {
    padding: 0px 15px 15px 15px !important;
    margin: 0px !important;
}

.hide {
    display: none !important;
}


.button-33 {
	width: 33% !important;
}

.button-33 .ui-btn-inner {
	padding-left: 0px;
	padding-right: 0px;
}

.maximize .ui-controlgroup-controls{
	width: 100% !important;
}

.min-width-480px .ui-controlgroup-label{
	width: 20% !important;
	margin: 0px !important;
}

.min-width-480px .ui-controlgroup-controls{
	width: 80% !important;
	
}

.pan-control a {
	margin: 0px !important;
}

.pan-control .ui-block-a,
	.pan-control .ui-block-b,
	.pan-control .ui-block-c {
	width: 36px !important;
}

.pan-control .ui-icon-delete {
	background-position: -1000px 50%;
}

.min-width-480px .ui-select {
    width: 100% !important;
}

.min-width-480px .ui-controlgroup input.ui-input-text, 
    .min-width-480px .ui-controlgroup textarea.ui-input-text, 
    .min-width-480px .ui-controlgroup .ui-input-search {
    width: 99% !important;
}

.ui-slider {
    width: 85% !important;
    height: 36px !important;
}

.ui-slider .ui-slider-handle {
    top: 3px !important;
    left: 0px;
}

#loading {
    top: 0px;
    left: 0px;
    width: 100%;
    height: 100%;
    position: absolute;
    background: blue;
    z-index: 1000;
}

#loading h1 {
    left: 50%;
    top: 50%;
    width: 300px;
    height: 3em;
    position: absolute;
    margin: -1.5em 0 0 -150px;
}
