.ui-tabs-content {
	display: none;
}

.ui-tabs-content-active {
	display: block;
}

#tab-video.ui-tabs-content {
	visibility: hidden;
	display: block !important;
	width: 0px;
	height: 0px;
}

#tab-video.ui-tabs-content-active {
	visibility: visible !important;
	width: 100%;
	height: 100%;
}
